// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMN_A32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMN_A32_H_

const byte kInstruction_cmn_ls_r10_0x00ab0000[] = {
  0xab, 0x08, 0x7a, 0x93 // cmn ls r10 0x00ab0000
};
const byte kInstruction_cmn_ls_r13_0xf000000f[] = {
  0xff, 0x02, 0x7d, 0x93 // cmn ls r13 0xf000000f
};
const byte kInstruction_cmn_pl_r4_0x00003fc0[] = {
  0xff, 0x0d, 0x74, 0x53 // cmn pl r4 0x00003fc0
};
const byte kInstruction_cmn_ne_r15_0x00ab0000[] = {
  0xab, 0x08, 0x7f, 0x13 // cmn ne r15 0x00ab0000
};
const byte kInstruction_cmn_lt_r14_0x002ac000[] = {
  0xab, 0x09, 0x7e, 0xb3 // cmn lt r14 0x002ac000
};
const byte kInstruction_cmn_eq_r15_0x000000ab[] = {
  0xab, 0x00, 0x7f, 0x03 // cmn eq r15 0x000000ab
};
const byte kInstruction_cmn_al_r6_0x002ac000[] = {
  0xab, 0x09, 0x76, 0xe3 // cmn al r6 0x002ac000
};
const byte kInstruction_cmn_pl_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x72, 0x53 // cmn pl r2 0x0002ac00
};
const byte kInstruction_cmn_mi_r8_0x00000000[] = {
  0x00, 0x00, 0x78, 0x43 // cmn mi r8 0x00000000
};
const byte kInstruction_cmn_pl_r13_0x02ac0000[] = {
  0xab, 0x07, 0x7d, 0x53 // cmn pl r13 0x02ac0000
};
const byte kInstruction_cmn_ge_r9_0xac000002[] = {
  0xab, 0x03, 0x79, 0xa3 // cmn ge r9 0xac000002
};
const byte kInstruction_cmn_ne_r3_0x000003fc[] = {
  0xff, 0x0f, 0x73, 0x13 // cmn ne r3 0x000003fc
};
const byte kInstruction_cmn_pl_r10_0xf000000f[] = {
  0xff, 0x02, 0x7a, 0x53 // cmn pl r10 0xf000000f
};
const byte kInstruction_cmn_cc_r0_0x00003fc0[] = {
  0xff, 0x0d, 0x70, 0x33 // cmn cc r0 0x00003fc0
};
const byte kInstruction_cmn_gt_r6_0x002ac000[] = {
  0xab, 0x09, 0x76, 0xc3 // cmn gt r6 0x002ac000
};
const byte kInstruction_cmn_cs_r1_0x00ff0000[] = {
  0xff, 0x08, 0x71, 0x23 // cmn cs r1 0x00ff0000
};
const byte kInstruction_cmn_lt_r8_0x000002ac[] = {
  0xab, 0x0f, 0x78, 0xb3 // cmn lt r8 0x000002ac
};
const byte kInstruction_cmn_vc_r4_0x2ac00000[] = {
  0xab, 0x05, 0x74, 0x73 // cmn vc r4 0x2ac00000
};
const byte kInstruction_cmn_al_r11_0x00003fc0[] = {
  0xff, 0x0d, 0x7b, 0xe3 // cmn al r11 0x00003fc0
};
const byte kInstruction_cmn_lt_r9_0x000000ab[] = {
  0xab, 0x00, 0x79, 0xb3 // cmn lt r9 0x000000ab
};
const byte kInstruction_cmn_le_r15_0x0000ff00[] = {
  0xff, 0x0c, 0x7f, 0xd3 // cmn le r15 0x0000ff00
};
const byte kInstruction_cmn_vc_r9_0xff000000[] = {
  0xff, 0x04, 0x79, 0x73 // cmn vc r9 0xff000000
};
const byte kInstruction_cmn_ge_r0_0x0ff00000[] = {
  0xff, 0x06, 0x70, 0xa3 // cmn ge r0 0x0ff00000
};
const byte kInstruction_cmn_vc_r1_0x00ff0000[] = {
  0xff, 0x08, 0x71, 0x73 // cmn vc r1 0x00ff0000
};
const byte kInstruction_cmn_vs_r12_0x00000ff0[] = {
  0xff, 0x0e, 0x7c, 0x63 // cmn vs r12 0x00000ff0
};
const byte kInstruction_cmn_pl_r13_0x003fc000[] = {
  0xff, 0x09, 0x7d, 0x53 // cmn pl r13 0x003fc000
};
const byte kInstruction_cmn_eq_r4_0xff000000[] = {
  0xff, 0x04, 0x74, 0x03 // cmn eq r4 0xff000000
};
const byte kInstruction_cmn_eq_r12_0xac000002[] = {
  0xab, 0x03, 0x7c, 0x03 // cmn eq r12 0xac000002
};
const byte kInstruction_cmn_al_r11_0x000000ab[] = {
  0xab, 0x00, 0x7b, 0xe3 // cmn al r11 0x000000ab
};
const byte kInstruction_cmn_ge_r10_0x00ff0000[] = {
  0xff, 0x08, 0x7a, 0xa3 // cmn ge r10 0x00ff0000
};
const byte kInstruction_cmn_vs_r7_0x0002ac00[] = {
  0xab, 0x0b, 0x77, 0x63 // cmn vs r7 0x0002ac00
};
const byte kInstruction_cmn_le_r7_0x002ac000[] = {
  0xab, 0x09, 0x77, 0xd3 // cmn le r7 0x002ac000
};
const byte kInstruction_cmn_vc_r9_0x000003fc[] = {
  0xff, 0x0f, 0x79, 0x73 // cmn vc r9 0x000003fc
};
const byte kInstruction_cmn_vs_r14_0x002ac000[] = {
  0xab, 0x09, 0x7e, 0x63 // cmn vs r14 0x002ac000
};
const byte kInstruction_cmn_vs_r1_0x000003fc[] = {
  0xff, 0x0f, 0x71, 0x63 // cmn vs r1 0x000003fc
};
const byte kInstruction_cmn_le_r13_0x3fc00000[] = {
  0xff, 0x05, 0x7d, 0xd3 // cmn le r13 0x3fc00000
};
const byte kInstruction_cmn_ne_r9_0x0002ac00[] = {
  0xab, 0x0b, 0x79, 0x13 // cmn ne r9 0x0002ac00
};
const byte kInstruction_cmn_al_r0_0x00ab0000[] = {
  0xab, 0x08, 0x70, 0xe3 // cmn al r0 0x00ab0000
};
const byte kInstruction_cmn_hi_r5_0xff000000[] = {
  0xff, 0x04, 0x75, 0x83 // cmn hi r5 0xff000000
};
const byte kInstruction_cmn_hi_r14_0x000000ab[] = {
  0xab, 0x00, 0x7e, 0x83 // cmn hi r14 0x000000ab
};
const byte kInstruction_cmn_hi_r14_0x000003fc[] = {
  0xff, 0x0f, 0x7e, 0x83 // cmn hi r14 0x000003fc
};
const byte kInstruction_cmn_mi_r14_0x03fc0000[] = {
  0xff, 0x07, 0x7e, 0x43 // cmn mi r14 0x03fc0000
};
const byte kInstruction_cmn_mi_r8_0x000000ff[] = {
  0xff, 0x00, 0x78, 0x43 // cmn mi r8 0x000000ff
};
const byte kInstruction_cmn_gt_r6_0x000ab000[] = {
  0xab, 0x0a, 0x76, 0xc3 // cmn gt r6 0x000ab000
};
const byte kInstruction_cmn_mi_r12_0x0ff00000[] = {
  0xff, 0x06, 0x7c, 0x43 // cmn mi r12 0x0ff00000
};
const byte kInstruction_cmn_vs_r3_0xff000000[] = {
  0xff, 0x04, 0x73, 0x63 // cmn vs r3 0xff000000
};
const byte kInstruction_cmn_vc_r7_0x00ab0000[] = {
  0xab, 0x08, 0x77, 0x73 // cmn vc r7 0x00ab0000
};
const byte kInstruction_cmn_hi_r6_0x03fc0000[] = {
  0xff, 0x07, 0x76, 0x83 // cmn hi r6 0x03fc0000
};
const byte kInstruction_cmn_ls_r5_0x00ab0000[] = {
  0xab, 0x08, 0x75, 0x93 // cmn ls r5 0x00ab0000
};
const byte kInstruction_cmn_ls_r4_0x000002ac[] = {
  0xab, 0x0f, 0x74, 0x93 // cmn ls r4 0x000002ac
};
const byte kInstruction_cmn_le_r13_0x03fc0000[] = {
  0xff, 0x07, 0x7d, 0xd3 // cmn le r13 0x03fc0000
};
const byte kInstruction_cmn_le_r15_0x002ac000[] = {
  0xab, 0x09, 0x7f, 0xd3 // cmn le r15 0x002ac000
};
const byte kInstruction_cmn_pl_r6_0xff000000[] = {
  0xff, 0x04, 0x76, 0x53 // cmn pl r6 0xff000000
};
const byte kInstruction_cmn_gt_r7_0x00000ab0[] = {
  0xab, 0x0e, 0x77, 0xc3 // cmn gt r7 0x00000ab0
};
const byte kInstruction_cmn_hi_r3_0x2ac00000[] = {
  0xab, 0x05, 0x73, 0x83 // cmn hi r3 0x2ac00000
};
const byte kInstruction_cmn_gt_r15_0x00000000[] = {
  0x00, 0x00, 0x7f, 0xc3 // cmn gt r15 0x00000000
};
const byte kInstruction_cmn_gt_r1_0x002ac000[] = {
  0xab, 0x09, 0x71, 0xc3 // cmn gt r1 0x002ac000
};
const byte kInstruction_cmn_hi_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x72, 0x83 // cmn hi r2 0x0000ff00
};
const byte kInstruction_cmn_pl_r10_0x03fc0000[] = {
  0xff, 0x07, 0x7a, 0x53 // cmn pl r10 0x03fc0000
};
const byte kInstruction_cmn_gt_r10_0xb000000a[] = {
  0xab, 0x02, 0x7a, 0xc3 // cmn gt r10 0xb000000a
};
const byte kInstruction_cmn_ge_r10_0x002ac000[] = {
  0xab, 0x09, 0x7a, 0xa3 // cmn ge r10 0x002ac000
};
const byte kInstruction_cmn_al_r4_0x0ab00000[] = {
  0xab, 0x06, 0x74, 0xe3 // cmn al r4 0x0ab00000
};
const byte kInstruction_cmn_ne_r12_0x00000000[] = {
  0x00, 0x00, 0x7c, 0x13 // cmn ne r12 0x00000000
};
const byte kInstruction_cmn_cs_r5_0x00003fc0[] = {
  0xff, 0x0d, 0x75, 0x23 // cmn cs r5 0x00003fc0
};
const byte kInstruction_cmn_cc_r6_0x000000ff[] = {
  0xff, 0x00, 0x76, 0x33 // cmn cc r6 0x000000ff
};
const byte kInstruction_cmn_hi_r14_0x03fc0000[] = {
  0xff, 0x07, 0x7e, 0x83 // cmn hi r14 0x03fc0000
};
const byte kInstruction_cmn_hi_r3_0xab000000[] = {
  0xab, 0x04, 0x73, 0x83 // cmn hi r3 0xab000000
};
const byte kInstruction_cmn_lt_r2_0x000ff000[] = {
  0xff, 0x0a, 0x72, 0xb3 // cmn lt r2 0x000ff000
};
const byte kInstruction_cmn_gt_r3_0x00ff0000[] = {
  0xff, 0x08, 0x73, 0xc3 // cmn gt r3 0x00ff0000
};
const byte kInstruction_cmn_le_r14_0x0ab00000[] = {
  0xab, 0x06, 0x7e, 0xd3 // cmn le r14 0x0ab00000
};
const byte kInstruction_cmn_cc_r13_0x03fc0000[] = {
  0xff, 0x07, 0x7d, 0x33 // cmn cc r13 0x03fc0000
};
const byte kInstruction_cmn_gt_r6_0xb000000a[] = {
  0xab, 0x02, 0x76, 0xc3 // cmn gt r6 0xb000000a
};
const byte kInstruction_cmn_pl_r3_0x2ac00000[] = {
  0xab, 0x05, 0x73, 0x53 // cmn pl r3 0x2ac00000
};
const byte kInstruction_cmn_mi_r15_0x000000ff[] = {
  0xff, 0x00, 0x7f, 0x43 // cmn mi r15 0x000000ff
};
const byte kInstruction_cmn_gt_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x74, 0xc3 // cmn gt r4 0x00000ff0
};
const byte kInstruction_cmn_ne_r4_0x000003fc[] = {
  0xff, 0x0f, 0x74, 0x13 // cmn ne r4 0x000003fc
};
const byte kInstruction_cmn_ne_r5_0x00ff0000[] = {
  0xff, 0x08, 0x75, 0x13 // cmn ne r5 0x00ff0000
};
const byte kInstruction_cmn_ge_r7_0x000003fc[] = {
  0xff, 0x0f, 0x77, 0xa3 // cmn ge r7 0x000003fc
};
const byte kInstruction_cmn_vs_r5_0x00000000[] = {
  0x00, 0x00, 0x75, 0x63 // cmn vs r5 0x00000000
};
const byte kInstruction_cmn_vs_r6_0x2ac00000[] = {
  0xab, 0x05, 0x76, 0x63 // cmn vs r6 0x2ac00000
};
const byte kInstruction_cmn_mi_r1_0x3fc00000[] = {
  0xff, 0x05, 0x71, 0x43 // cmn mi r1 0x3fc00000
};
const byte kInstruction_cmn_gt_r8_0xc000002a[] = {
  0xab, 0x01, 0x78, 0xc3 // cmn gt r8 0xc000002a
};
const byte kInstruction_cmn_pl_r10_0x000000ab[] = {
  0xab, 0x00, 0x7a, 0x53 // cmn pl r10 0x000000ab
};
const byte kInstruction_cmn_mi_r6_0xab000000[] = {
  0xab, 0x04, 0x76, 0x43 // cmn mi r6 0xab000000
};
const byte kInstruction_cmn_ls_r12_0x3fc00000[] = {
  0xff, 0x05, 0x7c, 0x93 // cmn ls r12 0x3fc00000
};
const byte kInstruction_cmn_vs_r13_0x03fc0000[] = {
  0xff, 0x07, 0x7d, 0x63 // cmn vs r13 0x03fc0000
};
const byte kInstruction_cmn_eq_r8_0x00000ab0[] = {
  0xab, 0x0e, 0x78, 0x03 // cmn eq r8 0x00000ab0
};
const byte kInstruction_cmn_gt_r6_0x000000ff[] = {
  0xff, 0x00, 0x76, 0xc3 // cmn gt r6 0x000000ff
};
const byte kInstruction_cmn_vs_r5_0x000ab000[] = {
  0xab, 0x0a, 0x75, 0x63 // cmn vs r5 0x000ab000
};
const byte kInstruction_cmn_mi_r1_0x2ac00000[] = {
  0xab, 0x05, 0x71, 0x43 // cmn mi r1 0x2ac00000
};
const byte kInstruction_cmn_vs_r6_0x00003fc0[] = {
  0xff, 0x0d, 0x76, 0x63 // cmn vs r6 0x00003fc0
};
const byte kInstruction_cmn_gt_r6_0x000002ac[] = {
  0xab, 0x0f, 0x76, 0xc3 // cmn gt r6 0x000002ac
};
const byte kInstruction_cmn_eq_r2_0x00000000[] = {
  0x00, 0x00, 0x72, 0x03 // cmn eq r2 0x00000000
};
const byte kInstruction_cmn_eq_r10_0xc000003f[] = {
  0xff, 0x01, 0x7a, 0x03 // cmn eq r10 0xc000003f
};
const byte kInstruction_cmn_mi_r7_0x00ab0000[] = {
  0xab, 0x08, 0x77, 0x43 // cmn mi r7 0x00ab0000
};
const byte kInstruction_cmn_cc_r7_0x2ac00000[] = {
  0xab, 0x05, 0x77, 0x33 // cmn cc r7 0x2ac00000
};
const byte kInstruction_cmn_pl_r4_0x00ab0000[] = {
  0xab, 0x08, 0x74, 0x53 // cmn pl r4 0x00ab0000
};
const byte kInstruction_cmn_ne_r15_0x00000ff0[] = {
  0xff, 0x0e, 0x7f, 0x13 // cmn ne r15 0x00000ff0
};
const byte kInstruction_cmn_al_r6_0x02ac0000[] = {
  0xab, 0x07, 0x76, 0xe3 // cmn al r6 0x02ac0000
};
const byte kInstruction_cmn_pl_r6_0x000002ac[] = {
  0xab, 0x0f, 0x76, 0x53 // cmn pl r6 0x000002ac
};
const byte kInstruction_cmn_ne_r14_0x00ff0000[] = {
  0xff, 0x08, 0x7e, 0x13 // cmn ne r14 0x00ff0000
};
const byte kInstruction_cmn_ne_r5_0x0003fc00[] = {
  0xff, 0x0b, 0x75, 0x13 // cmn ne r5 0x0003fc00
};
const byte kInstruction_cmn_pl_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x76, 0x53 // cmn pl r6 0x00000ab0
};
const byte kInstruction_cmn_eq_r10_0x00002ac0[] = {
  0xab, 0x0d, 0x7a, 0x03 // cmn eq r10 0x00002ac0
};
const byte kInstruction_cmn_mi_r4_0x00000ab0[] = {
  0xab, 0x0e, 0x74, 0x43 // cmn mi r4 0x00000ab0
};
const byte kInstruction_cmn_vc_r5_0x000ab000[] = {
  0xab, 0x0a, 0x75, 0x73 // cmn vc r5 0x000ab000
};
const byte kInstruction_cmn_ge_r0_0x02ac0000[] = {
  0xab, 0x07, 0x70, 0xa3 // cmn ge r0 0x02ac0000
};
const byte kInstruction_cmn_pl_r5_0x000002ac[] = {
  0xab, 0x0f, 0x75, 0x53 // cmn pl r5 0x000002ac
};
const byte kInstruction_cmn_ge_r13_0x00000ab0[] = {
  0xab, 0x0e, 0x7d, 0xa3 // cmn ge r13 0x00000ab0
};
const byte kInstruction_cmn_eq_r2_0x03fc0000[] = {
  0xff, 0x07, 0x72, 0x03 // cmn eq r2 0x03fc0000
};
const byte kInstruction_cmn_lt_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x7b, 0xb3 // cmn lt r11 0x00000ab0
};
const byte kInstruction_cmn_ge_r6_0x00000000[] = {
  0x00, 0x00, 0x76, 0xa3 // cmn ge r6 0x00000000
};
const byte kInstruction_cmn_gt_r2_0xac000002[] = {
  0xab, 0x03, 0x72, 0xc3 // cmn gt r2 0xac000002
};
const byte kInstruction_cmn_le_r15_0x000000ab[] = {
  0xab, 0x00, 0x7f, 0xd3 // cmn le r15 0x000000ab
};
const byte kInstruction_cmn_cc_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x74, 0x33 // cmn cc r4 0x00000ff0
};
const byte kInstruction_cmn_pl_r10_0x02ac0000[] = {
  0xab, 0x07, 0x7a, 0x53 // cmn pl r10 0x02ac0000
};
const byte kInstruction_cmn_gt_r9_0x00000000[] = {
  0x00, 0x00, 0x79, 0xc3 // cmn gt r9 0x00000000
};
const byte kInstruction_cmn_vs_r8_0x000000ff[] = {
  0xff, 0x00, 0x78, 0x63 // cmn vs r8 0x000000ff
};
const byte kInstruction_cmn_gt_r14_0x0002ac00[] = {
  0xab, 0x0b, 0x7e, 0xc3 // cmn gt r14 0x0002ac00
};
const byte kInstruction_cmn_vs_r14_0x00002ac0[] = {
  0xab, 0x0d, 0x7e, 0x63 // cmn vs r14 0x00002ac0
};
const byte kInstruction_cmn_ge_r12_0x00000000[] = {
  0x00, 0x00, 0x7c, 0xa3 // cmn ge r12 0x00000000
};
const byte kInstruction_cmn_vc_r8_0xf000000f[] = {
  0xff, 0x02, 0x78, 0x73 // cmn vc r8 0xf000000f
};
const byte kInstruction_cmn_cs_r6_0x00003fc0[] = {
  0xff, 0x0d, 0x76, 0x23 // cmn cs r6 0x00003fc0
};
const byte kInstruction_cmn_le_r4_0x000003fc[] = {
  0xff, 0x0f, 0x74, 0xd3 // cmn le r4 0x000003fc
};
const byte kInstruction_cmn_cs_r5_0x000ff000[] = {
  0xff, 0x0a, 0x75, 0x23 // cmn cs r5 0x000ff000
};
const byte kInstruction_cmn_eq_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x72, 0x03 // cmn eq r2 0x0000ff00
};
const byte kInstruction_cmn_pl_r10_0x0ab00000[] = {
  0xab, 0x06, 0x7a, 0x53 // cmn pl r10 0x0ab00000
};
const byte kInstruction_cmn_le_r11_0xac000002[] = {
  0xab, 0x03, 0x7b, 0xd3 // cmn le r11 0xac000002
};
const byte kInstruction_cmn_vs_r15_0x00003fc0[] = {
  0xff, 0x0d, 0x7f, 0x63 // cmn vs r15 0x00003fc0
};
const byte kInstruction_cmn_lt_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x72, 0xb3 // cmn lt r2 0x0002ac00
};
const byte kInstruction_cmn_eq_r1_0x00ab0000[] = {
  0xab, 0x08, 0x71, 0x03 // cmn eq r1 0x00ab0000
};
const byte kInstruction_cmn_cc_r7_0x03fc0000[] = {
  0xff, 0x07, 0x77, 0x33 // cmn cc r7 0x03fc0000
};
const byte kInstruction_cmn_mi_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x76, 0x43 // cmn mi r6 0x00000ab0
};
const byte kInstruction_cmn_eq_r4_0x00000ab0[] = {
  0xab, 0x0e, 0x74, 0x03 // cmn eq r4 0x00000ab0
};
const byte kInstruction_cmn_ls_r3_0x0003fc00[] = {
  0xff, 0x0b, 0x73, 0x93 // cmn ls r3 0x0003fc00
};
const byte kInstruction_cmn_mi_r6_0x000ab000[] = {
  0xab, 0x0a, 0x76, 0x43 // cmn mi r6 0x000ab000
};
const byte kInstruction_cmn_ne_r12_0x003fc000[] = {
  0xff, 0x09, 0x7c, 0x13 // cmn ne r12 0x003fc000
};
const byte kInstruction_cmn_eq_r11_0x00ff0000[] = {
  0xff, 0x08, 0x7b, 0x03 // cmn eq r11 0x00ff0000
};
const byte kInstruction_cmn_cs_r13_0x00ab0000[] = {
  0xab, 0x08, 0x7d, 0x23 // cmn cs r13 0x00ab0000
};
const byte kInstruction_cmn_eq_r5_0x000003fc[] = {
  0xff, 0x0f, 0x75, 0x03 // cmn eq r5 0x000003fc
};
const byte kInstruction_cmn_vs_r6_0x0003fc00[] = {
  0xff, 0x0b, 0x76, 0x63 // cmn vs r6 0x0003fc00
};
const byte kInstruction_cmn_pl_r8_0x0ff00000[] = {
  0xff, 0x06, 0x78, 0x53 // cmn pl r8 0x0ff00000
};
const byte kInstruction_cmn_pl_r11_0x0000ab00[] = {
  0xab, 0x0c, 0x7b, 0x53 // cmn pl r11 0x0000ab00
};
const byte kInstruction_cmn_le_r2_0xac000002[] = {
  0xab, 0x03, 0x72, 0xd3 // cmn le r2 0xac000002
};
const byte kInstruction_cmn_vc_r10_0x000ff000[] = {
  0xff, 0x0a, 0x7a, 0x73 // cmn vc r10 0x000ff000
};
const byte kInstruction_cmn_le_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x74, 0xd3 // cmn le r4 0x00000ff0
};
const byte kInstruction_cmn_gt_r12_0x00000ff0[] = {
  0xff, 0x0e, 0x7c, 0xc3 // cmn gt r12 0x00000ff0
};
const byte kInstruction_cmn_le_r5_0x0002ac00[] = {
  0xab, 0x0b, 0x75, 0xd3 // cmn le r5 0x0002ac00
};
const byte kInstruction_cmn_le_r0_0xac000002[] = {
  0xab, 0x03, 0x70, 0xd3 // cmn le r0 0xac000002
};
const byte kInstruction_cmn_vs_r11_0x0ff00000[] = {
  0xff, 0x06, 0x7b, 0x63 // cmn vs r11 0x0ff00000
};
const byte kInstruction_cmn_ls_r0_0x000ab000[] = {
  0xab, 0x0a, 0x70, 0x93 // cmn ls r0 0x000ab000
};
const byte kInstruction_cmn_ls_r2_0xf000000f[] = {
  0xff, 0x02, 0x72, 0x93 // cmn ls r2 0xf000000f
};
const byte kInstruction_cmn_cs_r3_0x0ff00000[] = {
  0xff, 0x06, 0x73, 0x23 // cmn cs r3 0x0ff00000
};
const byte kInstruction_cmn_hi_r8_0x0ff00000[] = {
  0xff, 0x06, 0x78, 0x83 // cmn hi r8 0x0ff00000
};
const byte kInstruction_cmn_gt_r3_0x00002ac0[] = {
  0xab, 0x0d, 0x73, 0xc3 // cmn gt r3 0x00002ac0
};
const byte kInstruction_cmn_al_r15_0xab000000[] = {
  0xab, 0x04, 0x7f, 0xe3 // cmn al r15 0xab000000
};
const byte kInstruction_cmn_eq_r13_0x000000ab[] = {
  0xab, 0x00, 0x7d, 0x03 // cmn eq r13 0x000000ab
};
const byte kInstruction_cmn_al_r2_0xc000002a[] = {
  0xab, 0x01, 0x72, 0xe3 // cmn al r2 0xc000002a
};
const byte kInstruction_cmn_eq_r13_0x03fc0000[] = {
  0xff, 0x07, 0x7d, 0x03 // cmn eq r13 0x03fc0000
};
const byte kInstruction_cmn_eq_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x73, 0x03 // cmn eq r3 0x00000ff0
};
const byte kInstruction_cmn_hi_r12_0x00002ac0[] = {
  0xab, 0x0d, 0x7c, 0x83 // cmn hi r12 0x00002ac0
};
const byte kInstruction_cmn_mi_r2_0x0ff00000[] = {
  0xff, 0x06, 0x72, 0x43 // cmn mi r2 0x0ff00000
};
const byte kInstruction_cmn_ne_r9_0x003fc000[] = {
  0xff, 0x09, 0x79, 0x13 // cmn ne r9 0x003fc000
};
const byte kInstruction_cmn_eq_r14_0x03fc0000[] = {
  0xff, 0x07, 0x7e, 0x03 // cmn eq r14 0x03fc0000
};
const byte kInstruction_cmn_cc_r0_0x002ac000[] = {
  0xab, 0x09, 0x70, 0x33 // cmn cc r0 0x002ac000
};
const byte kInstruction_cmn_vc_r14_0x00000ab0[] = {
  0xab, 0x0e, 0x7e, 0x73 // cmn vc r14 0x00000ab0
};
const byte kInstruction_cmn_mi_r15_0xf000000f[] = {
  0xff, 0x02, 0x7f, 0x43 // cmn mi r15 0xf000000f
};
const byte kInstruction_cmn_ge_r9_0x000003fc[] = {
  0xff, 0x0f, 0x79, 0xa3 // cmn ge r9 0x000003fc
};
const byte kInstruction_cmn_vs_r13_0xac000002[] = {
  0xab, 0x03, 0x7d, 0x63 // cmn vs r13 0xac000002
};
const byte kInstruction_cmn_vs_r1_0x3fc00000[] = {
  0xff, 0x05, 0x71, 0x63 // cmn vs r1 0x3fc00000
};
const byte kInstruction_cmn_eq_r12_0x00003fc0[] = {
  0xff, 0x0d, 0x7c, 0x03 // cmn eq r12 0x00003fc0
};
const byte kInstruction_cmn_mi_r6_0xff000000[] = {
  0xff, 0x04, 0x76, 0x43 // cmn mi r6 0xff000000
};
const byte kInstruction_cmn_ne_r5_0x000003fc[] = {
  0xff, 0x0f, 0x75, 0x13 // cmn ne r5 0x000003fc
};
const byte kInstruction_cmn_lt_r8_0x0ff00000[] = {
  0xff, 0x06, 0x78, 0xb3 // cmn lt r8 0x0ff00000
};
const byte kInstruction_cmn_hi_r7_0x3fc00000[] = {
  0xff, 0x05, 0x77, 0x83 // cmn hi r7 0x3fc00000
};
const byte kInstruction_cmn_ge_r10_0xac000002[] = {
  0xab, 0x03, 0x7a, 0xa3 // cmn ge r10 0xac000002
};
const byte kInstruction_cmn_vs_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x72, 0x63 // cmn vs r2 0x0000ff00
};
const byte kInstruction_cmn_al_r6_0x000000ab[] = {
  0xab, 0x00, 0x76, 0xe3 // cmn al r6 0x000000ab
};
const byte kInstruction_cmn_ge_r7_0x00ff0000[] = {
  0xff, 0x08, 0x77, 0xa3 // cmn ge r7 0x00ff0000
};
const byte kInstruction_cmn_ne_r0_0x000ff000[] = {
  0xff, 0x0a, 0x70, 0x13 // cmn ne r0 0x000ff000
};
const byte kInstruction_cmn_mi_r6_0x000000ab[] = {
  0xab, 0x00, 0x76, 0x43 // cmn mi r6 0x000000ab
};
const byte kInstruction_cmn_hi_r1_0xf000000f[] = {
  0xff, 0x02, 0x71, 0x83 // cmn hi r1 0xf000000f
};
const byte kInstruction_cmn_mi_r6_0x2ac00000[] = {
  0xab, 0x05, 0x76, 0x43 // cmn mi r6 0x2ac00000
};
const byte kInstruction_cmn_vc_r11_0x000000ff[] = {
  0xff, 0x00, 0x7b, 0x73 // cmn vc r11 0x000000ff
};
const byte kInstruction_cmn_ls_r14_0x02ac0000[] = {
  0xab, 0x07, 0x7e, 0x93 // cmn ls r14 0x02ac0000
};
const byte kInstruction_cmn_ge_r5_0x003fc000[] = {
  0xff, 0x09, 0x75, 0xa3 // cmn ge r5 0x003fc000
};
const byte kInstruction_cmn_ls_r12_0x0000ab00[] = {
  0xab, 0x0c, 0x7c, 0x93 // cmn ls r12 0x0000ab00
};
const byte kInstruction_cmn_cc_r15_0x00000ab0[] = {
  0xab, 0x0e, 0x7f, 0x33 // cmn cc r15 0x00000ab0
};
const byte kInstruction_cmn_vc_r12_0x0000ab00[] = {
  0xab, 0x0c, 0x7c, 0x73 // cmn vc r12 0x0000ab00
};
const byte kInstruction_cmn_vs_r2_0xc000002a[] = {
  0xab, 0x01, 0x72, 0x63 // cmn vs r2 0xc000002a
};
const byte kInstruction_cmn_lt_r7_0x0ab00000[] = {
  0xab, 0x06, 0x77, 0xb3 // cmn lt r7 0x0ab00000
};
const byte kInstruction_cmn_ls_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x76, 0x93 // cmn ls r6 0x00000ff0
};
const byte kInstruction_cmn_vc_r10_0x000000ff[] = {
  0xff, 0x00, 0x7a, 0x73 // cmn vc r10 0x000000ff
};
const byte kInstruction_cmn_ls_r4_0x0000ab00[] = {
  0xab, 0x0c, 0x74, 0x93 // cmn ls r4 0x0000ab00
};
const byte kInstruction_cmn_mi_r10_0x003fc000[] = {
  0xff, 0x09, 0x7a, 0x43 // cmn mi r10 0x003fc000
};
const byte kInstruction_cmn_ls_r1_0x000002ac[] = {
  0xab, 0x0f, 0x71, 0x93 // cmn ls r1 0x000002ac
};
const byte kInstruction_cmn_ge_r7_0xb000000a[] = {
  0xab, 0x02, 0x77, 0xa3 // cmn ge r7 0xb000000a
};
const byte kInstruction_cmn_gt_r4_0xf000000f[] = {
  0xff, 0x02, 0x74, 0xc3 // cmn gt r4 0xf000000f
};
const byte kInstruction_cmn_vc_r8_0x002ac000[] = {
  0xab, 0x09, 0x78, 0x73 // cmn vc r8 0x002ac000
};
const byte kInstruction_cmn_eq_r5_0x0ab00000[] = {
  0xab, 0x06, 0x75, 0x03 // cmn eq r5 0x0ab00000
};
const byte kInstruction_cmn_gt_r2_0xf000000f[] = {
  0xff, 0x02, 0x72, 0xc3 // cmn gt r2 0xf000000f
};
const byte kInstruction_cmn_gt_r6_0xff000000[] = {
  0xff, 0x04, 0x76, 0xc3 // cmn gt r6 0xff000000
};
const byte kInstruction_cmn_ls_r8_0x0ab00000[] = {
  0xab, 0x06, 0x78, 0x93 // cmn ls r8 0x0ab00000
};
const byte kInstruction_cmn_vc_r0_0xb000000a[] = {
  0xab, 0x02, 0x70, 0x73 // cmn vc r0 0xb000000a
};
const byte kInstruction_cmn_lt_r6_0x03fc0000[] = {
  0xff, 0x07, 0x76, 0xb3 // cmn lt r6 0x03fc0000
};
const byte kInstruction_cmn_ge_r10_0x0000ab00[] = {
  0xab, 0x0c, 0x7a, 0xa3 // cmn ge r10 0x0000ab00
};
const byte kInstruction_cmn_hi_r4_0x000ab000[] = {
  0xab, 0x0a, 0x74, 0x83 // cmn hi r4 0x000ab000
};
const byte kInstruction_cmn_hi_r11_0x3fc00000[] = {
  0xff, 0x05, 0x7b, 0x83 // cmn hi r11 0x3fc00000
};
const byte kInstruction_cmn_vs_r12_0xc000003f[] = {
  0xff, 0x01, 0x7c, 0x63 // cmn vs r12 0xc000003f
};
const byte kInstruction_cmn_gt_r12_0xb000000a[] = {
  0xab, 0x02, 0x7c, 0xc3 // cmn gt r12 0xb000000a
};
const byte kInstruction_cmn_eq_r11_0x2ac00000[] = {
  0xab, 0x05, 0x7b, 0x03 // cmn eq r11 0x2ac00000
};
const byte kInstruction_cmn_hi_r0_0xc000003f[] = {
  0xff, 0x01, 0x70, 0x83 // cmn hi r0 0xc000003f
};
const byte kInstruction_cmn_cs_r12_0xac000002[] = {
  0xab, 0x03, 0x7c, 0x23 // cmn cs r12 0xac000002
};
const byte kInstruction_cmn_hi_r9_0x3fc00000[] = {
  0xff, 0x05, 0x79, 0x83 // cmn hi r9 0x3fc00000
};
const byte kInstruction_cmn_vs_r2_0x00002ac0[] = {
  0xab, 0x0d, 0x72, 0x63 // cmn vs r2 0x00002ac0
};
const byte kInstruction_cmn_al_r12_0xb000000a[] = {
  0xab, 0x02, 0x7c, 0xe3 // cmn al r12 0xb000000a
};
const byte kInstruction_cmn_gt_r12_0x3fc00000[] = {
  0xff, 0x05, 0x7c, 0xc3 // cmn gt r12 0x3fc00000
};
const byte kInstruction_cmn_gt_r6_0xf000000f[] = {
  0xff, 0x02, 0x76, 0xc3 // cmn gt r6 0xf000000f
};
const byte kInstruction_cmn_vc_r14_0x000000ff[] = {
  0xff, 0x00, 0x7e, 0x73 // cmn vc r14 0x000000ff
};
const byte kInstruction_cmn_pl_r7_0x0002ac00[] = {
  0xab, 0x0b, 0x77, 0x53 // cmn pl r7 0x0002ac00
};
const byte kInstruction_cmn_ge_r1_0x03fc0000[] = {
  0xff, 0x07, 0x71, 0xa3 // cmn ge r1 0x03fc0000
};
const byte kInstruction_cmn_hi_r10_0x0002ac00[] = {
  0xab, 0x0b, 0x7a, 0x83 // cmn hi r10 0x0002ac00
};
const byte kInstruction_cmn_gt_r4_0x002ac000[] = {
  0xab, 0x09, 0x74, 0xc3 // cmn gt r4 0x002ac000
};
const byte kInstruction_cmn_vc_r5_0x000000ff[] = {
  0xff, 0x00, 0x75, 0x73 // cmn vc r5 0x000000ff
};
const byte kInstruction_cmn_pl_r15_0x0000ab00[] = {
  0xab, 0x0c, 0x7f, 0x53 // cmn pl r15 0x0000ab00
};
const byte kInstruction_cmn_cc_r4_0x00ab0000[] = {
  0xab, 0x08, 0x74, 0x33 // cmn cc r4 0x00ab0000
};
const byte kInstruction_cmn_pl_r11_0xff000000[] = {
  0xff, 0x04, 0x7b, 0x53 // cmn pl r11 0xff000000
};
const byte kInstruction_cmn_pl_r2_0xf000000f[] = {
  0xff, 0x02, 0x72, 0x53 // cmn pl r2 0xf000000f
};
const byte kInstruction_cmn_cc_r8_0xb000000a[] = {
  0xab, 0x02, 0x78, 0x33 // cmn cc r8 0xb000000a
};
const byte kInstruction_cmn_al_r13_0x000000ff[] = {
  0xff, 0x00, 0x7d, 0xe3 // cmn al r13 0x000000ff
};
const byte kInstruction_cmn_mi_r6_0x000003fc[] = {
  0xff, 0x0f, 0x76, 0x43 // cmn mi r6 0x000003fc
};
const byte kInstruction_cmn_vs_r13_0x02ac0000[] = {
  0xab, 0x07, 0x7d, 0x63 // cmn vs r13 0x02ac0000
};
const byte kInstruction_cmn_mi_r4_0x00ff0000[] = {
  0xff, 0x08, 0x74, 0x43 // cmn mi r4 0x00ff0000
};
const byte kInstruction_cmn_cs_r3_0x000003fc[] = {
  0xff, 0x0f, 0x73, 0x23 // cmn cs r3 0x000003fc
};
const byte kInstruction_cmn_pl_r13_0xab000000[] = {
  0xab, 0x04, 0x7d, 0x53 // cmn pl r13 0xab000000
};
const byte kInstruction_cmn_ls_r9_0x002ac000[] = {
  0xab, 0x09, 0x79, 0x93 // cmn ls r9 0x002ac000
};
const byte kInstruction_cmn_eq_r1_0xc000002a[] = {
  0xab, 0x01, 0x71, 0x03 // cmn eq r1 0xc000002a
};
const byte kInstruction_cmn_lt_r12_0x00000000[] = {
  0x00, 0x00, 0x7c, 0xb3 // cmn lt r12 0x00000000
};
const byte kInstruction_cmn_ge_r14_0xff000000[] = {
  0xff, 0x04, 0x7e, 0xa3 // cmn ge r14 0xff000000
};
const byte kInstruction_cmn_lt_r9_0x002ac000[] = {
  0xab, 0x09, 0x79, 0xb3 // cmn lt r9 0x002ac000
};
const byte kInstruction_cmn_lt_r10_0x00000ff0[] = {
  0xff, 0x0e, 0x7a, 0xb3 // cmn lt r10 0x00000ff0
};
const byte kInstruction_cmn_vs_r5_0x000000ff[] = {
  0xff, 0x00, 0x75, 0x63 // cmn vs r5 0x000000ff
};
const byte kInstruction_cmn_cc_r12_0x03fc0000[] = {
  0xff, 0x07, 0x7c, 0x33 // cmn cc r12 0x03fc0000
};
const byte kInstruction_cmn_ne_r4_0x00000000[] = {
  0x00, 0x00, 0x74, 0x13 // cmn ne r4 0x00000000
};
const byte kInstruction_cmn_mi_r13_0xff000000[] = {
  0xff, 0x04, 0x7d, 0x43 // cmn mi r13 0xff000000
};
const byte kInstruction_cmn_ne_r7_0x00000ff0[] = {
  0xff, 0x0e, 0x77, 0x13 // cmn ne r7 0x00000ff0
};
const byte kInstruction_cmn_vs_r2_0xc000003f[] = {
  0xff, 0x01, 0x72, 0x63 // cmn vs r2 0xc000003f
};
const byte kInstruction_cmn_al_r5_0x00ff0000[] = {
  0xff, 0x08, 0x75, 0xe3 // cmn al r5 0x00ff0000
};
const byte kInstruction_cmn_hi_r15_0x00000ff0[] = {
  0xff, 0x0e, 0x7f, 0x83 // cmn hi r15 0x00000ff0
};
const byte kInstruction_cmn_ls_r8_0x00003fc0[] = {
  0xff, 0x0d, 0x78, 0x93 // cmn ls r8 0x00003fc0
};
const byte kInstruction_cmn_vs_r0_0xff000000[] = {
  0xff, 0x04, 0x70, 0x63 // cmn vs r0 0xff000000
};
const byte kInstruction_cmn_vs_r6_0x000000ab[] = {
  0xab, 0x00, 0x76, 0x63 // cmn vs r6 0x000000ab
};
const byte kInstruction_cmn_cs_r9_0x00ab0000[] = {
  0xab, 0x08, 0x79, 0x23 // cmn cs r9 0x00ab0000
};
const byte kInstruction_cmn_hi_r1_0x0002ac00[] = {
  0xab, 0x0b, 0x71, 0x83 // cmn hi r1 0x0002ac00
};
const byte kInstruction_cmn_hi_r15_0x2ac00000[] = {
  0xab, 0x05, 0x7f, 0x83 // cmn hi r15 0x2ac00000
};
const byte kInstruction_cmn_hi_r6_0x0002ac00[] = {
  0xab, 0x0b, 0x76, 0x83 // cmn hi r6 0x0002ac00
};
const byte kInstruction_cmn_ge_r4_0xc000003f[] = {
  0xff, 0x01, 0x74, 0xa3 // cmn ge r4 0xc000003f
};
const byte kInstruction_cmn_ls_r10_0x0000ff00[] = {
  0xff, 0x0c, 0x7a, 0x93 // cmn ls r10 0x0000ff00
};
const byte kInstruction_cmn_ne_r11_0x000003fc[] = {
  0xff, 0x0f, 0x7b, 0x13 // cmn ne r11 0x000003fc
};
const byte kInstruction_cmn_ls_r3_0x0002ac00[] = {
  0xab, 0x0b, 0x73, 0x93 // cmn ls r3 0x0002ac00
};
const byte kInstruction_cmn_al_r12_0x000003fc[] = {
  0xff, 0x0f, 0x7c, 0xe3 // cmn al r12 0x000003fc
};
const byte kInstruction_cmn_le_r7_0xf000000f[] = {
  0xff, 0x02, 0x77, 0xd3 // cmn le r7 0xf000000f
};
const byte kInstruction_cmn_al_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x7b, 0xe3 // cmn al r11 0x00000ab0
};
const byte kInstruction_cmn_cs_r13_0x02ac0000[] = {
  0xab, 0x07, 0x7d, 0x23 // cmn cs r13 0x02ac0000
};
const byte kInstruction_cmn_hi_r1_0x00000ff0[] = {
  0xff, 0x0e, 0x71, 0x83 // cmn hi r1 0x00000ff0
};
const byte kInstruction_cmn_le_r11_0x3fc00000[] = {
  0xff, 0x05, 0x7b, 0xd3 // cmn le r11 0x3fc00000
};
const byte kInstruction_cmn_hi_r9_0x000003fc[] = {
  0xff, 0x0f, 0x79, 0x83 // cmn hi r9 0x000003fc
};
const byte kInstruction_cmn_mi_r13_0x000002ac[] = {
  0xab, 0x0f, 0x7d, 0x43 // cmn mi r13 0x000002ac
};
const byte kInstruction_cmn_lt_r12_0x000003fc[] = {
  0xff, 0x0f, 0x7c, 0xb3 // cmn lt r12 0x000003fc
};
const byte kInstruction_cmn_lt_r14_0x00000ab0[] = {
  0xab, 0x0e, 0x7e, 0xb3 // cmn lt r14 0x00000ab0
};
const byte kInstruction_cmn_gt_r1_0x3fc00000[] = {
  0xff, 0x05, 0x71, 0xc3 // cmn gt r1 0x3fc00000
};
const byte kInstruction_cmn_cc_r14_0xb000000a[] = {
  0xab, 0x02, 0x7e, 0x33 // cmn cc r14 0xb000000a
};
const byte kInstruction_cmn_ge_r0_0x000002ac[] = {
  0xab, 0x0f, 0x70, 0xa3 // cmn ge r0 0x000002ac
};
const byte kInstruction_cmn_eq_r12_0x000003fc[] = {
  0xff, 0x0f, 0x7c, 0x03 // cmn eq r12 0x000003fc
};
const byte kInstruction_cmn_vc_r13_0x0ab00000[] = {
  0xab, 0x06, 0x7d, 0x73 // cmn vc r13 0x0ab00000
};
const byte kInstruction_cmn_pl_r10_0x0003fc00[] = {
  0xff, 0x0b, 0x7a, 0x53 // cmn pl r10 0x0003fc00
};
const byte kInstruction_cmn_le_r7_0x0000ff00[] = {
  0xff, 0x0c, 0x77, 0xd3 // cmn le r7 0x0000ff00
};
const byte kInstruction_cmn_eq_r5_0x0003fc00[] = {
  0xff, 0x0b, 0x75, 0x03 // cmn eq r5 0x0003fc00
};
const byte kInstruction_cmn_pl_r1_0xfc000003[] = {
  0xff, 0x03, 0x71, 0x53 // cmn pl r1 0xfc000003
};
const byte kInstruction_cmn_gt_r15_0x000ff000[] = {
  0xff, 0x0a, 0x7f, 0xc3 // cmn gt r15 0x000ff000
};
const byte kInstruction_cmn_mi_r2_0xb000000a[] = {
  0xab, 0x02, 0x72, 0x43 // cmn mi r2 0xb000000a
};
const byte kInstruction_cmn_cs_r8_0x0000ff00[] = {
  0xff, 0x0c, 0x78, 0x23 // cmn cs r8 0x0000ff00
};
const byte kInstruction_cmn_vs_r8_0x00002ac0[] = {
  0xab, 0x0d, 0x78, 0x63 // cmn vs r8 0x00002ac0
};
const byte kInstruction_cmn_cs_r5_0x00ab0000[] = {
  0xab, 0x08, 0x75, 0x23 // cmn cs r5 0x00ab0000
};
const byte kInstruction_cmn_pl_r3_0x00ab0000[] = {
  0xab, 0x08, 0x73, 0x53 // cmn pl r3 0x00ab0000
};
const byte kInstruction_cmn_hi_r5_0x02ac0000[] = {
  0xab, 0x07, 0x75, 0x83 // cmn hi r5 0x02ac0000
};
const byte kInstruction_cmn_cc_r9_0x000002ac[] = {
  0xab, 0x0f, 0x79, 0x33 // cmn cc r9 0x000002ac
};
const byte kInstruction_cmn_ls_r13_0x0000ab00[] = {
  0xab, 0x0c, 0x7d, 0x93 // cmn ls r13 0x0000ab00
};
const byte kInstruction_cmn_pl_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x7b, 0x53 // cmn pl r11 0x00000ab0
};
const byte kInstruction_cmn_ge_r14_0x3fc00000[] = {
  0xff, 0x05, 0x7e, 0xa3 // cmn ge r14 0x3fc00000
};
const byte kInstruction_cmn_al_r14_0x0000ab00[] = {
  0xab, 0x0c, 0x7e, 0xe3 // cmn al r14 0x0000ab00
};
const byte kInstruction_cmn_lt_r6_0xac000002[] = {
  0xab, 0x03, 0x76, 0xb3 // cmn lt r6 0xac000002
};
const byte kInstruction_cmn_vc_r3_0x000ff000[] = {
  0xff, 0x0a, 0x73, 0x73 // cmn vc r3 0x000ff000
};
const byte kInstruction_cmn_ne_r8_0xfc000003[] = {
  0xff, 0x03, 0x78, 0x13 // cmn ne r8 0xfc000003
};
const byte kInstruction_cmn_cs_r6_0x000ab000[] = {
  0xab, 0x0a, 0x76, 0x23 // cmn cs r6 0x000ab000
};
const byte kInstruction_cmn_hi_r15_0x0002ac00[] = {
  0xab, 0x0b, 0x7f, 0x83 // cmn hi r15 0x0002ac00
};
const byte kInstruction_cmn_pl_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x76, 0x53 // cmn pl r6 0x00000ff0
};
const byte kInstruction_cmn_hi_r15_0x03fc0000[] = {
  0xff, 0x07, 0x7f, 0x83 // cmn hi r15 0x03fc0000
};
const byte kInstruction_cmn_cc_r6_0x0003fc00[] = {
  0xff, 0x0b, 0x76, 0x33 // cmn cc r6 0x0003fc00
};
const byte kInstruction_cmn_eq_r12_0x000002ac[] = {
  0xab, 0x0f, 0x7c, 0x03 // cmn eq r12 0x000002ac
};
const byte kInstruction_cmn_ls_r11_0x02ac0000[] = {
  0xab, 0x07, 0x7b, 0x93 // cmn ls r11 0x02ac0000
};
const byte kInstruction_cmn_ge_r13_0x00ff0000[] = {
  0xff, 0x08, 0x7d, 0xa3 // cmn ge r13 0x00ff0000
};
const byte kInstruction_cmn_lt_r4_0x0003fc00[] = {
  0xff, 0x0b, 0x74, 0xb3 // cmn lt r4 0x0003fc00
};
const byte kInstruction_cmn_mi_r0_0x0000ab00[] = {
  0xab, 0x0c, 0x70, 0x43 // cmn mi r0 0x0000ab00
};
const byte kInstruction_cmn_lt_r4_0x000000ab[] = {
  0xab, 0x00, 0x74, 0xb3 // cmn lt r4 0x000000ab
};
const byte kInstruction_cmn_ls_r2_0xc000003f[] = {
  0xff, 0x01, 0x72, 0x93 // cmn ls r2 0xc000003f
};
const byte kInstruction_cmn_pl_r1_0x000000ab[] = {
  0xab, 0x00, 0x71, 0x53 // cmn pl r1 0x000000ab
};
const byte kInstruction_cmn_ne_r10_0x0000ff00[] = {
  0xff, 0x0c, 0x7a, 0x13 // cmn ne r10 0x0000ff00
};
const byte kInstruction_cmn_vc_r15_0x00000ab0[] = {
  0xab, 0x0e, 0x7f, 0x73 // cmn vc r15 0x00000ab0
};
const byte kInstruction_cmn_eq_r6_0x02ac0000[] = {
  0xab, 0x07, 0x76, 0x03 // cmn eq r6 0x02ac0000
};
const byte kInstruction_cmn_cc_r11_0x00000000[] = {
  0x00, 0x00, 0x7b, 0x33 // cmn cc r11 0x00000000
};
const byte kInstruction_cmn_mi_r7_0x002ac000[] = {
  0xab, 0x09, 0x77, 0x43 // cmn mi r7 0x002ac000
};
const byte kInstruction_cmn_hi_r14_0xab000000[] = {
  0xab, 0x04, 0x7e, 0x83 // cmn hi r14 0xab000000
};
const byte kInstruction_cmn_vc_r6_0x0000ff00[] = {
  0xff, 0x0c, 0x76, 0x73 // cmn vc r6 0x0000ff00
};
const byte kInstruction_cmn_al_r5_0x000002ac[] = {
  0xab, 0x0f, 0x75, 0xe3 // cmn al r5 0x000002ac
};
const byte kInstruction_cmn_cc_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x7c, 0x33 // cmn cc r12 0x0002ac00
};
const byte kInstruction_cmn_cc_r10_0x000000ab[] = {
  0xab, 0x00, 0x7a, 0x33 // cmn cc r10 0x000000ab
};
const byte kInstruction_cmn_gt_r5_0x000002ac[] = {
  0xab, 0x0f, 0x75, 0xc3 // cmn gt r5 0x000002ac
};
const byte kInstruction_cmn_vc_r3_0x00000000[] = {
  0x00, 0x00, 0x73, 0x73 // cmn vc r3 0x00000000
};
const byte kInstruction_cmn_gt_r12_0xac000002[] = {
  0xab, 0x03, 0x7c, 0xc3 // cmn gt r12 0xac000002
};
const byte kInstruction_cmn_al_r10_0x00ab0000[] = {
  0xab, 0x08, 0x7a, 0xe3 // cmn al r10 0x00ab0000
};
const byte kInstruction_cmn_mi_r5_0x000ff000[] = {
  0xff, 0x0a, 0x75, 0x43 // cmn mi r5 0x000ff000
};
const byte kInstruction_cmn_pl_r1_0x00000ff0[] = {
  0xff, 0x0e, 0x71, 0x53 // cmn pl r1 0x00000ff0
};
const byte kInstruction_cmn_lt_r7_0xf000000f[] = {
  0xff, 0x02, 0x77, 0xb3 // cmn lt r7 0xf000000f
};
const byte kInstruction_cmn_ge_r14_0x002ac000[] = {
  0xab, 0x09, 0x7e, 0xa3 // cmn ge r14 0x002ac000
};
const byte kInstruction_cmn_cc_r0_0xac000002[] = {
  0xab, 0x03, 0x70, 0x33 // cmn cc r0 0xac000002
};
const byte kInstruction_cmn_cs_r2_0x00000ab0[] = {
  0xab, 0x0e, 0x72, 0x23 // cmn cs r2 0x00000ab0
};
const byte kInstruction_cmn_vs_r0_0x00002ac0[] = {
  0xab, 0x0d, 0x70, 0x63 // cmn vs r0 0x00002ac0
};
const byte kInstruction_cmn_le_r10_0x000ab000[] = {
  0xab, 0x0a, 0x7a, 0xd3 // cmn le r10 0x000ab000
};
const byte kInstruction_cmn_ge_r9_0x0003fc00[] = {
  0xff, 0x0b, 0x79, 0xa3 // cmn ge r9 0x0003fc00
};
const byte kInstruction_cmn_lt_r1_0x00003fc0[] = {
  0xff, 0x0d, 0x71, 0xb3 // cmn lt r1 0x00003fc0
};
const byte kInstruction_cmn_ge_r5_0x000000ff[] = {
  0xff, 0x00, 0x75, 0xa3 // cmn ge r5 0x000000ff
};
const byte kInstruction_cmn_le_r11_0x2ac00000[] = {
  0xab, 0x05, 0x7b, 0xd3 // cmn le r11 0x2ac00000
};
const byte kInstruction_cmn_le_r9_0x002ac000[] = {
  0xab, 0x09, 0x79, 0xd3 // cmn le r9 0x002ac000
};
const byte kInstruction_cmn_hi_r12_0xf000000f[] = {
  0xff, 0x02, 0x7c, 0x83 // cmn hi r12 0xf000000f
};
const byte kInstruction_cmn_lt_r3_0x02ac0000[] = {
  0xab, 0x07, 0x73, 0xb3 // cmn lt r3 0x02ac0000
};
const byte kInstruction_cmn_al_r13_0x2ac00000[] = {
  0xab, 0x05, 0x7d, 0xe3 // cmn al r13 0x2ac00000
};
const byte kInstruction_cmn_vs_r12_0x00000ab0[] = {
  0xab, 0x0e, 0x7c, 0x63 // cmn vs r12 0x00000ab0
};
const byte kInstruction_cmn_gt_r3_0x3fc00000[] = {
  0xff, 0x05, 0x73, 0xc3 // cmn gt r3 0x3fc00000
};
const byte kInstruction_cmn_gt_r0_0x2ac00000[] = {
  0xab, 0x05, 0x70, 0xc3 // cmn gt r0 0x2ac00000
};
const byte kInstruction_cmn_eq_r15_0x000002ac[] = {
  0xab, 0x0f, 0x7f, 0x03 // cmn eq r15 0x000002ac
};
const byte kInstruction_cmn_gt_r1_0x000ab000[] = {
  0xab, 0x0a, 0x71, 0xc3 // cmn gt r1 0x000ab000
};
const byte kInstruction_cmn_gt_r2_0x2ac00000[] = {
  0xab, 0x05, 0x72, 0xc3 // cmn gt r2 0x2ac00000
};
const byte kInstruction_cmn_mi_r15_0x00ab0000[] = {
  0xab, 0x08, 0x7f, 0x43 // cmn mi r15 0x00ab0000
};
const byte kInstruction_cmn_mi_r1_0x000ab000[] = {
  0xab, 0x0a, 0x71, 0x43 // cmn mi r1 0x000ab000
};
const byte kInstruction_cmn_ge_r12_0x0ab00000[] = {
  0xab, 0x06, 0x7c, 0xa3 // cmn ge r12 0x0ab00000
};
const byte kInstruction_cmn_gt_r5_0x000000ab[] = {
  0xab, 0x00, 0x75, 0xc3 // cmn gt r5 0x000000ab
};
const byte kInstruction_cmn_gt_r4_0x00000000[] = {
  0x00, 0x00, 0x74, 0xc3 // cmn gt r4 0x00000000
};
const byte kInstruction_cmn_al_r13_0xc000003f[] = {
  0xff, 0x01, 0x7d, 0xe3 // cmn al r13 0xc000003f
};
const byte kInstruction_cmn_ls_r7_0xff000000[] = {
  0xff, 0x04, 0x77, 0x93 // cmn ls r7 0xff000000
};
const byte kInstruction_cmn_vs_r0_0x00000ff0[] = {
  0xff, 0x0e, 0x70, 0x63 // cmn vs r0 0x00000ff0
};
const byte kInstruction_cmn_hi_r9_0x02ac0000[] = {
  0xab, 0x07, 0x79, 0x83 // cmn hi r9 0x02ac0000
};
const byte kInstruction_cmn_cs_r1_0xc000002a[] = {
  0xab, 0x01, 0x71, 0x23 // cmn cs r1 0xc000002a
};
const byte kInstruction_cmn_hi_r8_0xf000000f[] = {
  0xff, 0x02, 0x78, 0x83 // cmn hi r8 0xf000000f
};
const byte kInstruction_cmn_gt_r1_0xb000000a[] = {
  0xab, 0x02, 0x71, 0xc3 // cmn gt r1 0xb000000a
};
const byte kInstruction_cmn_gt_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x72, 0xc3 // cmn gt r2 0x0002ac00
};
const byte kInstruction_cmn_vs_r5_0x000000ab[] = {
  0xab, 0x00, 0x75, 0x63 // cmn vs r5 0x000000ab
};
const byte kInstruction_cmn_cc_r12_0x000ff000[] = {
  0xff, 0x0a, 0x7c, 0x33 // cmn cc r12 0x000ff000
};
const byte kInstruction_cmn_ge_r0_0x00003fc0[] = {
  0xff, 0x0d, 0x70, 0xa3 // cmn ge r0 0x00003fc0
};
const byte kInstruction_cmn_ls_r12_0x00ab0000[] = {
  0xab, 0x08, 0x7c, 0x93 // cmn ls r12 0x00ab0000
};
const byte kInstruction_cmn_vs_r4_0x000003fc[] = {
  0xff, 0x0f, 0x74, 0x63 // cmn vs r4 0x000003fc
};
const byte kInstruction_cmn_ls_r4_0x00003fc0[] = {
  0xff, 0x0d, 0x74, 0x93 // cmn ls r4 0x00003fc0
};
const byte kInstruction_cmn_eq_r9_0xb000000a[] = {
  0xab, 0x02, 0x79, 0x03 // cmn eq r9 0xb000000a
};
const byte kInstruction_cmn_cs_r9_0x2ac00000[] = {
  0xab, 0x05, 0x79, 0x23 // cmn cs r9 0x2ac00000
};
const byte kInstruction_cmn_vs_r12_0x0000ff00[] = {
  0xff, 0x0c, 0x7c, 0x63 // cmn vs r12 0x0000ff00
};
const byte kInstruction_cmn_vc_r1_0x0000ff00[] = {
  0xff, 0x0c, 0x71, 0x73 // cmn vc r1 0x0000ff00
};
const byte kInstruction_cmn_hi_r12_0xff000000[] = {
  0xff, 0x04, 0x7c, 0x83 // cmn hi r12 0xff000000
};
const byte kInstruction_cmn_cs_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x7c, 0x23 // cmn cs r12 0x0002ac00
};
const byte kInstruction_cmn_mi_r11_0x03fc0000[] = {
  0xff, 0x07, 0x7b, 0x43 // cmn mi r11 0x03fc0000
};
const byte kInstruction_cmn_eq_r2_0x000ff000[] = {
  0xff, 0x0a, 0x72, 0x03 // cmn eq r2 0x000ff000
};
const byte kInstruction_cmn_al_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x76, 0xe3 // cmn al r6 0x00000ff0
};
const byte kInstruction_cmn_cs_r7_0x000003fc[] = {
  0xff, 0x0f, 0x77, 0x23 // cmn cs r7 0x000003fc
};
const byte kInstruction_cmn_pl_r11_0xb000000a[] = {
  0xab, 0x02, 0x7b, 0x53 // cmn pl r11 0xb000000a
};
const byte kInstruction_cmn_ne_r15_0x000ff000[] = {
  0xff, 0x0a, 0x7f, 0x13 // cmn ne r15 0x000ff000
};
const byte kInstruction_cmn_mi_r14_0x00ab0000[] = {
  0xab, 0x08, 0x7e, 0x43 // cmn mi r14 0x00ab0000
};
const byte kInstruction_cmn_hi_r4_0x0000ff00[] = {
  0xff, 0x0c, 0x74, 0x83 // cmn hi r4 0x0000ff00
};
const byte kInstruction_cmn_ge_r1_0x000002ac[] = {
  0xab, 0x0f, 0x71, 0xa3 // cmn ge r1 0x000002ac
};
const byte kInstruction_cmn_gt_r7_0xb000000a[] = {
  0xab, 0x02, 0x77, 0xc3 // cmn gt r7 0xb000000a
};
const byte kInstruction_cmn_gt_r2_0x00000000[] = {
  0x00, 0x00, 0x72, 0xc3 // cmn gt r2 0x00000000
};
const byte kInstruction_cmn_cc_r2_0xb000000a[] = {
  0xab, 0x02, 0x72, 0x33 // cmn cc r2 0xb000000a
};
const byte kInstruction_cmn_vs_r14_0x000ab000[] = {
  0xab, 0x0a, 0x7e, 0x63 // cmn vs r14 0x000ab000
};
const byte kInstruction_cmn_lt_r5_0x000002ac[] = {
  0xab, 0x0f, 0x75, 0xb3 // cmn lt r5 0x000002ac
};
const byte kInstruction_cmn_cc_r13_0x0000ff00[] = {
  0xff, 0x0c, 0x7d, 0x33 // cmn cc r13 0x0000ff00
};
const byte kInstruction_cmn_hi_r15_0x000002ac[] = {
  0xab, 0x0f, 0x7f, 0x83 // cmn hi r15 0x000002ac
};
const byte kInstruction_cmn_ge_r1_0x00ff0000[] = {
  0xff, 0x08, 0x71, 0xa3 // cmn ge r1 0x00ff0000
};
const byte kInstruction_cmn_lt_r15_0x00002ac0[] = {
  0xab, 0x0d, 0x7f, 0xb3 // cmn lt r15 0x00002ac0
};
const byte kInstruction_cmn_lt_r8_0x000ff000[] = {
  0xff, 0x0a, 0x78, 0xb3 // cmn lt r8 0x000ff000
};
const byte kInstruction_cmn_hi_r10_0xc000002a[] = {
  0xab, 0x01, 0x7a, 0x83 // cmn hi r10 0xc000002a
};
const byte kInstruction_cmn_eq_r12_0x000ab000[] = {
  0xab, 0x0a, 0x7c, 0x03 // cmn eq r12 0x000ab000
};
const byte kInstruction_cmn_vs_r11_0x00002ac0[] = {
  0xab, 0x0d, 0x7b, 0x63 // cmn vs r11 0x00002ac0
};
const byte kInstruction_cmn_hi_r10_0x000003fc[] = {
  0xff, 0x0f, 0x7a, 0x83 // cmn hi r10 0x000003fc
};
const byte kInstruction_cmn_cc_r8_0x000003fc[] = {
  0xff, 0x0f, 0x78, 0x33 // cmn cc r8 0x000003fc
};
const byte kInstruction_cmn_vc_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x7b, 0x73 // cmn vc r11 0x00000ab0
};
const byte kInstruction_cmn_le_r3_0xac000002[] = {
  0xab, 0x03, 0x73, 0xd3 // cmn le r3 0xac000002
};
const byte kInstruction_cmn_cc_r11_0xc000002a[] = {
  0xab, 0x01, 0x7b, 0x33 // cmn cc r11 0xc000002a
};
const byte kInstruction_cmn_lt_r6_0xab000000[] = {
  0xab, 0x04, 0x76, 0xb3 // cmn lt r6 0xab000000
};
const byte kInstruction_cmn_hi_r1_0x00003fc0[] = {
  0xff, 0x0d, 0x71, 0x83 // cmn hi r1 0x00003fc0
};
const byte kInstruction_cmn_vc_r3_0x00002ac0[] = {
  0xab, 0x0d, 0x73, 0x73 // cmn vc r3 0x00002ac0
};
const byte kInstruction_cmn_vc_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x76, 0x73 // cmn vc r6 0x00000ab0
};
const byte kInstruction_cmn_ls_r6_0x03fc0000[] = {
  0xff, 0x07, 0x76, 0x93 // cmn ls r6 0x03fc0000
};
const byte kInstruction_cmn_hi_r11_0x0ab00000[] = {
  0xab, 0x06, 0x7b, 0x83 // cmn hi r11 0x0ab00000
};
const byte kInstruction_cmn_lt_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x7c, 0xb3 // cmn lt r12 0x0002ac00
};
const byte kInstruction_cmn_al_r8_0xab000000[] = {
  0xab, 0x04, 0x78, 0xe3 // cmn al r8 0xab000000
};
const byte kInstruction_cmn_vs_r2_0x00000ab0[] = {
  0xab, 0x0e, 0x72, 0x63 // cmn vs r2 0x00000ab0
};
const byte kInstruction_cmn_hi_r14_0x02ac0000[] = {
  0xab, 0x07, 0x7e, 0x83 // cmn hi r14 0x02ac0000
};
const byte kInstruction_cmn_cs_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x73, 0x23 // cmn cs r3 0x00000ff0
};
const byte kInstruction_cmn_cc_r9_0xb000000a[] = {
  0xab, 0x02, 0x79, 0x33 // cmn cc r9 0xb000000a
};
const byte kInstruction_cmn_vc_r9_0x00000ff0[] = {
  0xff, 0x0e, 0x79, 0x73 // cmn vc r9 0x00000ff0
};
const byte kInstruction_cmn_ne_r9_0xab000000[] = {
  0xab, 0x04, 0x79, 0x13 // cmn ne r9 0xab000000
};
const byte kInstruction_cmn_cc_r10_0xb000000a[] = {
  0xab, 0x02, 0x7a, 0x33 // cmn cc r10 0xb000000a
};
const byte kInstruction_cmn_ls_r11_0xb000000a[] = {
  0xab, 0x02, 0x7b, 0x93 // cmn ls r11 0xb000000a
};
const byte kInstruction_cmn_lt_r11_0x00ff0000[] = {
  0xff, 0x08, 0x7b, 0xb3 // cmn lt r11 0x00ff0000
};
const byte kInstruction_cmn_lt_r3_0x000003fc[] = {
  0xff, 0x0f, 0x73, 0xb3 // cmn lt r3 0x000003fc
};
const byte kInstruction_cmn_gt_r14_0x00002ac0[] = {
  0xab, 0x0d, 0x7e, 0xc3 // cmn gt r14 0x00002ac0
};
const byte kInstruction_cmn_ls_r8_0xc000003f[] = {
  0xff, 0x01, 0x78, 0x93 // cmn ls r8 0xc000003f
};
const byte kInstruction_cmn_al_r11_0x000ab000[] = {
  0xab, 0x0a, 0x7b, 0xe3 // cmn al r11 0x000ab000
};
const byte kInstruction_cmn_lt_r7_0x000ab000[] = {
  0xab, 0x0a, 0x77, 0xb3 // cmn lt r7 0x000ab000
};
const byte kInstruction_cmn_vs_r14_0xff000000[] = {
  0xff, 0x04, 0x7e, 0x63 // cmn vs r14 0xff000000
};
const byte kInstruction_cmn_vc_r2_0xab000000[] = {
  0xab, 0x04, 0x72, 0x73 // cmn vc r2 0xab000000
};
const byte kInstruction_cmn_ne_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x73, 0x13 // cmn ne r3 0x00000ff0
};
const byte kInstruction_cmn_ne_r15_0x02ac0000[] = {
  0xab, 0x07, 0x7f, 0x13 // cmn ne r15 0x02ac0000
};
const byte kInstruction_cmn_gt_r3_0x000ff000[] = {
  0xff, 0x0a, 0x73, 0xc3 // cmn gt r3 0x000ff000
};
const byte kInstruction_cmn_pl_r1_0x2ac00000[] = {
  0xab, 0x05, 0x71, 0x53 // cmn pl r1 0x2ac00000
};
const byte kInstruction_cmn_mi_r1_0x00002ac0[] = {
  0xab, 0x0d, 0x71, 0x43 // cmn mi r1 0x00002ac0
};
const byte kInstruction_cmn_vc_r6_0xac000002[] = {
  0xab, 0x03, 0x76, 0x73 // cmn vc r6 0xac000002
};
const byte kInstruction_cmn_vs_r2_0x0ff00000[] = {
  0xff, 0x06, 0x72, 0x63 // cmn vs r2 0x0ff00000
};
const byte kInstruction_cmn_ge_r2_0x000003fc[] = {
  0xff, 0x0f, 0x72, 0xa3 // cmn ge r2 0x000003fc
};
const byte kInstruction_cmn_cs_r15_0x0000ff00[] = {
  0xff, 0x0c, 0x7f, 0x23 // cmn cs r15 0x0000ff00
};
const byte kInstruction_cmn_lt_r3_0x000002ac[] = {
  0xab, 0x0f, 0x73, 0xb3 // cmn lt r3 0x000002ac
};
const byte kInstruction_cmn_cs_r6_0xff000000[] = {
  0xff, 0x04, 0x76, 0x23 // cmn cs r6 0xff000000
};
const byte kInstruction_cmn_ge_r14_0x000000ff[] = {
  0xff, 0x00, 0x7e, 0xa3 // cmn ge r14 0x000000ff
};
const byte kInstruction_cmn_gt_r7_0x03fc0000[] = {
  0xff, 0x07, 0x77, 0xc3 // cmn gt r7 0x03fc0000
};
const byte kInstruction_cmn_ne_r8_0x000ff000[] = {
  0xff, 0x0a, 0x78, 0x13 // cmn ne r8 0x000ff000
};
const byte kInstruction_cmn_gt_r14_0xc000002a[] = {
  0xab, 0x01, 0x7e, 0xc3 // cmn gt r14 0xc000002a
};
const byte kInstruction_cmn_hi_r12_0x0000ff00[] = {
  0xff, 0x0c, 0x7c, 0x83 // cmn hi r12 0x0000ff00
};
const byte kInstruction_cmn_le_r15_0x00003fc0[] = {
  0xff, 0x0d, 0x7f, 0xd3 // cmn le r15 0x00003fc0
};
const byte kInstruction_cmn_eq_r13_0x000ab000[] = {
  0xab, 0x0a, 0x7d, 0x03 // cmn eq r13 0x000ab000
};
const byte kInstruction_cmn_vc_r7_0x000ab000[] = {
  0xab, 0x0a, 0x77, 0x73 // cmn vc r7 0x000ab000
};
const byte kInstruction_cmn_gt_r7_0xf000000f[] = {
  0xff, 0x02, 0x77, 0xc3 // cmn gt r7 0xf000000f
};
const byte kInstruction_cmn_cc_r6_0xac000002[] = {
  0xab, 0x03, 0x76, 0x33 // cmn cc r6 0xac000002
};
const byte kInstruction_cmn_cs_r14_0x000000ff[] = {
  0xff, 0x00, 0x7e, 0x23 // cmn cs r14 0x000000ff
};
const byte kInstruction_cmn_ne_r2_0x0003fc00[] = {
  0xff, 0x0b, 0x72, 0x13 // cmn ne r2 0x0003fc00
};
const byte kInstruction_cmn_vs_r1_0x002ac000[] = {
  0xab, 0x09, 0x71, 0x63 // cmn vs r1 0x002ac000
};
const byte kInstruction_cmn_eq_r8_0x002ac000[] = {
  0xab, 0x09, 0x78, 0x03 // cmn eq r8 0x002ac000
};
const byte kInstruction_cmn_lt_r8_0x0000ff00[] = {
  0xff, 0x0c, 0x78, 0xb3 // cmn lt r8 0x0000ff00
};
const byte kInstruction_cmn_vs_r9_0xc000003f[] = {
  0xff, 0x01, 0x79, 0x63 // cmn vs r9 0xc000003f
};
const byte kInstruction_cmn_mi_r11_0xff000000[] = {
  0xff, 0x04, 0x7b, 0x43 // cmn mi r11 0xff000000
};
const byte kInstruction_cmn_cs_r12_0x03fc0000[] = {
  0xff, 0x07, 0x7c, 0x23 // cmn cs r12 0x03fc0000
};
const byte kInstruction_cmn_lt_r5_0xc000002a[] = {
  0xab, 0x01, 0x75, 0xb3 // cmn lt r5 0xc000002a
};
const byte kInstruction_cmn_vc_r6_0x000000ab[] = {
  0xab, 0x00, 0x76, 0x73 // cmn vc r6 0x000000ab
};
const byte kInstruction_cmn_ls_r10_0x0ab00000[] = {
  0xab, 0x06, 0x7a, 0x93 // cmn ls r10 0x0ab00000
};
const byte kInstruction_cmn_al_r11_0x00ff0000[] = {
  0xff, 0x08, 0x7b, 0xe3 // cmn al r11 0x00ff0000
};
const byte kInstruction_cmn_hi_r13_0x00000ab0[] = {
  0xab, 0x0e, 0x7d, 0x83 // cmn hi r13 0x00000ab0
};
const byte kInstruction_cmn_ls_r0_0xab000000[] = {
  0xab, 0x04, 0x70, 0x93 // cmn ls r0 0xab000000
};
const byte kInstruction_cmn_le_r5_0xab000000[] = {
  0xab, 0x04, 0x75, 0xd3 // cmn le r5 0xab000000
};
const byte kInstruction_cmn_vs_r4_0x00ff0000[] = {
  0xff, 0x08, 0x74, 0x63 // cmn vs r4 0x00ff0000
};
const byte kInstruction_cmn_al_r10_0x03fc0000[] = {
  0xff, 0x07, 0x7a, 0xe3 // cmn al r10 0x03fc0000
};
const byte kInstruction_cmn_al_r8_0x000003fc[] = {
  0xff, 0x0f, 0x78, 0xe3 // cmn al r8 0x000003fc
};
const byte kInstruction_cmn_vs_r11_0xab000000[] = {
  0xab, 0x04, 0x7b, 0x63 // cmn vs r11 0xab000000
};
const byte kInstruction_cmn_eq_r2_0x00000ff0[] = {
  0xff, 0x0e, 0x72, 0x03 // cmn eq r2 0x00000ff0
};
const byte kInstruction_cmn_vc_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x74, 0x73 // cmn vc r4 0x00000ff0
};
const byte kInstruction_cmn_vc_r9_0x00002ac0[] = {
  0xab, 0x0d, 0x79, 0x73 // cmn vc r9 0x00002ac0
};
const byte kInstruction_cmn_cc_r11_0x00ff0000[] = {
  0xff, 0x08, 0x7b, 0x33 // cmn cc r11 0x00ff0000
};
const byte kInstruction_cmn_cc_r13_0x00ff0000[] = {
  0xff, 0x08, 0x7d, 0x33 // cmn cc r13 0x00ff0000
};
const byte kInstruction_cmn_pl_r0_0x00000ab0[] = {
  0xab, 0x0e, 0x70, 0x53 // cmn pl r0 0x00000ab0
};
const byte kInstruction_cmn_al_r2_0x02ac0000[] = {
  0xab, 0x07, 0x72, 0xe3 // cmn al r2 0x02ac0000
};
const byte kInstruction_cmn_hi_r11_0xc000002a[] = {
  0xab, 0x01, 0x7b, 0x83 // cmn hi r11 0xc000002a
};
const byte kInstruction_cmn_ne_r3_0xf000000f[] = {
  0xff, 0x02, 0x73, 0x13 // cmn ne r3 0xf000000f
};
const byte kInstruction_cmn_cc_r15_0x0ab00000[] = {
  0xab, 0x06, 0x7f, 0x33 // cmn cc r15 0x0ab00000
};
const byte kInstruction_cmn_ge_r12_0x00ff0000[] = {
  0xff, 0x08, 0x7c, 0xa3 // cmn ge r12 0x00ff0000
};
const byte kInstruction_cmn_le_r12_0x002ac000[] = {
  0xab, 0x09, 0x7c, 0xd3 // cmn le r12 0x002ac000
};
const byte kInstruction_cmn_mi_r12_0xc000003f[] = {
  0xff, 0x01, 0x7c, 0x43 // cmn mi r12 0xc000003f
};
const byte kInstruction_cmn_lt_r0_0xfc000003[] = {
  0xff, 0x03, 0x70, 0xb3 // cmn lt r0 0xfc000003
};
const byte kInstruction_cmn_vc_r15_0x000ab000[] = {
  0xab, 0x0a, 0x7f, 0x73 // cmn vc r15 0x000ab000
};
const byte kInstruction_cmn_pl_r5_0x3fc00000[] = {
  0xff, 0x05, 0x75, 0x53 // cmn pl r5 0x3fc00000
};
const byte kInstruction_cmn_vs_r15_0x00ab0000[] = {
  0xab, 0x08, 0x7f, 0x63 // cmn vs r15 0x00ab0000
};
const byte kInstruction_cmn_hi_r3_0x00ff0000[] = {
  0xff, 0x08, 0x73, 0x83 // cmn hi r3 0x00ff0000
};
const byte kInstruction_cmn_lt_r8_0x000000ff[] = {
  0xff, 0x00, 0x78, 0xb3 // cmn lt r8 0x000000ff
};
const byte kInstruction_cmn_le_r2_0x000000ff[] = {
  0xff, 0x00, 0x72, 0xd3 // cmn le r2 0x000000ff
};
const byte kInstruction_cmn_vs_r0_0x0002ac00[] = {
  0xab, 0x0b, 0x70, 0x63 // cmn vs r0 0x0002ac00
};
const byte kInstruction_cmn_vs_r2_0xff000000[] = {
  0xff, 0x04, 0x72, 0x63 // cmn vs r2 0xff000000
};
const byte kInstruction_cmn_pl_r6_0xab000000[] = {
  0xab, 0x04, 0x76, 0x53 // cmn pl r6 0xab000000
};
const byte kInstruction_cmn_ls_r4_0x3fc00000[] = {
  0xff, 0x05, 0x74, 0x93 // cmn ls r4 0x3fc00000
};
const byte kInstruction_cmn_ls_r3_0x000ab000[] = {
  0xab, 0x0a, 0x73, 0x93 // cmn ls r3 0x000ab000
};
const byte kInstruction_cmn_eq_r11_0x000ab000[] = {
  0xab, 0x0a, 0x7b, 0x03 // cmn eq r11 0x000ab000
};
const byte kInstruction_cmn_vc_r6_0x03fc0000[] = {
  0xff, 0x07, 0x76, 0x73 // cmn vc r6 0x03fc0000
};
const byte kInstruction_cmn_mi_r14_0x0000ab00[] = {
  0xab, 0x0c, 0x7e, 0x43 // cmn mi r14 0x0000ab00
};
const byte kInstruction_cmn_pl_r8_0xab000000[] = {
  0xab, 0x04, 0x78, 0x53 // cmn pl r8 0xab000000
};
const byte kInstruction_cmn_pl_r8_0xc000003f[] = {
  0xff, 0x01, 0x78, 0x53 // cmn pl r8 0xc000003f
};
const byte kInstruction_cmn_eq_r14_0x003fc000[] = {
  0xff, 0x09, 0x7e, 0x03 // cmn eq r14 0x003fc000
};
const byte kInstruction_cmn_vs_r9_0x00ff0000[] = {
  0xff, 0x08, 0x79, 0x63 // cmn vs r9 0x00ff0000
};
const byte kInstruction_cmn_vs_r1_0x00002ac0[] = {
  0xab, 0x0d, 0x71, 0x63 // cmn vs r1 0x00002ac0
};
const byte kInstruction_cmn_le_r1_0x00ff0000[] = {
  0xff, 0x08, 0x71, 0xd3 // cmn le r1 0x00ff0000
};
const byte kInstruction_cmn_lt_r7_0x000ff000[] = {
  0xff, 0x0a, 0x77, 0xb3 // cmn lt r7 0x000ff000
};
const byte kInstruction_cmn_mi_r6_0x002ac000[] = {
  0xab, 0x09, 0x76, 0x43 // cmn mi r6 0x002ac000
};
const byte kInstruction_cmn_vc_r11_0xc000003f[] = {
  0xff, 0x01, 0x7b, 0x73 // cmn vc r11 0xc000003f
};
const byte kInstruction_cmn_lt_r4_0x00000000[] = {
  0x00, 0x00, 0x74, 0xb3 // cmn lt r4 0x00000000
};
const byte kInstruction_cmn_pl_r0_0xac000002[] = {
  0xab, 0x03, 0x70, 0x53 // cmn pl r0 0xac000002
};
const byte kInstruction_cmn_ls_r10_0xc000003f[] = {
  0xff, 0x01, 0x7a, 0x93 // cmn ls r10 0xc000003f
};
const byte kInstruction_cmn_cc_r15_0xc000002a[] = {
  0xab, 0x01, 0x7f, 0x33 // cmn cc r15 0xc000002a
};
const TestResult kReferencecmn[] = {
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r10_0x00ab0000),
    kInstruction_cmn_ls_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r13_0xf000000f),
    kInstruction_cmn_ls_r13_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r4_0x00003fc0),
    kInstruction_cmn_pl_r4_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r15_0x00ab0000),
    kInstruction_cmn_ne_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r14_0x002ac000),
    kInstruction_cmn_lt_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r15_0x000000ab),
    kInstruction_cmn_eq_r15_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r6_0x002ac000),
    kInstruction_cmn_al_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r2_0x0002ac00),
    kInstruction_cmn_pl_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r8_0x00000000),
    kInstruction_cmn_mi_r8_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r13_0x02ac0000),
    kInstruction_cmn_pl_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r9_0xac000002),
    kInstruction_cmn_ge_r9_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r3_0x000003fc),
    kInstruction_cmn_ne_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0xf000000f),
    kInstruction_cmn_pl_r10_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r0_0x00003fc0),
    kInstruction_cmn_cc_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0x002ac000),
    kInstruction_cmn_gt_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r1_0x00ff0000),
    kInstruction_cmn_cs_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r8_0x000002ac),
    kInstruction_cmn_lt_r8_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r4_0x2ac00000),
    kInstruction_cmn_vc_r4_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r11_0x00003fc0),
    kInstruction_cmn_al_r11_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r9_0x000000ab),
    kInstruction_cmn_lt_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r15_0x0000ff00),
    kInstruction_cmn_le_r15_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r9_0xff000000),
    kInstruction_cmn_vc_r9_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r0_0x0ff00000),
    kInstruction_cmn_ge_r0_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r1_0x00ff0000),
    kInstruction_cmn_vc_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r12_0x00000ff0),
    kInstruction_cmn_vs_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r13_0x003fc000),
    kInstruction_cmn_pl_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r4_0xff000000),
    kInstruction_cmn_eq_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r12_0xac000002),
    kInstruction_cmn_eq_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r11_0x000000ab),
    kInstruction_cmn_al_r11_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r10_0x00ff0000),
    kInstruction_cmn_ge_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r7_0x0002ac00),
    kInstruction_cmn_vs_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r7_0x002ac000),
    kInstruction_cmn_le_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r9_0x000003fc),
    kInstruction_cmn_vc_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r14_0x002ac000),
    kInstruction_cmn_vs_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r1_0x000003fc),
    kInstruction_cmn_vs_r1_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r13_0x3fc00000),
    kInstruction_cmn_le_r13_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r9_0x0002ac00),
    kInstruction_cmn_ne_r9_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r0_0x00ab0000),
    kInstruction_cmn_al_r0_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r5_0xff000000),
    kInstruction_cmn_hi_r5_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r14_0x000000ab),
    kInstruction_cmn_hi_r14_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r14_0x000003fc),
    kInstruction_cmn_hi_r14_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r14_0x03fc0000),
    kInstruction_cmn_mi_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r8_0x000000ff),
    kInstruction_cmn_mi_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0x000ab000),
    kInstruction_cmn_gt_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r12_0x0ff00000),
    kInstruction_cmn_mi_r12_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r3_0xff000000),
    kInstruction_cmn_vs_r3_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r7_0x00ab0000),
    kInstruction_cmn_vc_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r6_0x03fc0000),
    kInstruction_cmn_hi_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r5_0x00ab0000),
    kInstruction_cmn_ls_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r4_0x000002ac),
    kInstruction_cmn_ls_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r13_0x03fc0000),
    kInstruction_cmn_le_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r15_0x002ac000),
    kInstruction_cmn_le_r15_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r6_0xff000000),
    kInstruction_cmn_pl_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r7_0x00000ab0),
    kInstruction_cmn_gt_r7_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r3_0x2ac00000),
    kInstruction_cmn_hi_r3_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r15_0x00000000),
    kInstruction_cmn_gt_r15_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r1_0x002ac000),
    kInstruction_cmn_gt_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r2_0x0000ff00),
    kInstruction_cmn_hi_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0x03fc0000),
    kInstruction_cmn_pl_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r10_0xb000000a),
    kInstruction_cmn_gt_r10_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r10_0x002ac000),
    kInstruction_cmn_ge_r10_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r4_0x0ab00000),
    kInstruction_cmn_al_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r12_0x00000000),
    kInstruction_cmn_ne_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r5_0x00003fc0),
    kInstruction_cmn_cs_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r6_0x000000ff),
    kInstruction_cmn_cc_r6_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r14_0x03fc0000),
    kInstruction_cmn_hi_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r3_0xab000000),
    kInstruction_cmn_hi_r3_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r2_0x000ff000),
    kInstruction_cmn_lt_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r3_0x00ff0000),
    kInstruction_cmn_gt_r3_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r14_0x0ab00000),
    kInstruction_cmn_le_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r13_0x03fc0000),
    kInstruction_cmn_cc_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0xb000000a),
    kInstruction_cmn_gt_r6_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r3_0x2ac00000),
    kInstruction_cmn_pl_r3_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r15_0x000000ff),
    kInstruction_cmn_mi_r15_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r4_0x00000ff0),
    kInstruction_cmn_gt_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r4_0x000003fc),
    kInstruction_cmn_ne_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r5_0x00ff0000),
    kInstruction_cmn_ne_r5_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r7_0x000003fc),
    kInstruction_cmn_ge_r7_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r5_0x00000000),
    kInstruction_cmn_vs_r5_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r6_0x2ac00000),
    kInstruction_cmn_vs_r6_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r1_0x3fc00000),
    kInstruction_cmn_mi_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r8_0xc000002a),
    kInstruction_cmn_gt_r8_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0x000000ab),
    kInstruction_cmn_pl_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0xab000000),
    kInstruction_cmn_mi_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r12_0x3fc00000),
    kInstruction_cmn_ls_r12_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r13_0x03fc0000),
    kInstruction_cmn_vs_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r8_0x00000ab0),
    kInstruction_cmn_eq_r8_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0x000000ff),
    kInstruction_cmn_gt_r6_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r5_0x000ab000),
    kInstruction_cmn_vs_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r1_0x2ac00000),
    kInstruction_cmn_mi_r1_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r6_0x00003fc0),
    kInstruction_cmn_vs_r6_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0x000002ac),
    kInstruction_cmn_gt_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r2_0x00000000),
    kInstruction_cmn_eq_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r10_0xc000003f),
    kInstruction_cmn_eq_r10_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r7_0x00ab0000),
    kInstruction_cmn_mi_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r7_0x2ac00000),
    kInstruction_cmn_cc_r7_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r4_0x00ab0000),
    kInstruction_cmn_pl_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r15_0x00000ff0),
    kInstruction_cmn_ne_r15_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r6_0x02ac0000),
    kInstruction_cmn_al_r6_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r6_0x000002ac),
    kInstruction_cmn_pl_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r14_0x00ff0000),
    kInstruction_cmn_ne_r14_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r5_0x0003fc00),
    kInstruction_cmn_ne_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r6_0x00000ab0),
    kInstruction_cmn_pl_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r10_0x00002ac0),
    kInstruction_cmn_eq_r10_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r4_0x00000ab0),
    kInstruction_cmn_mi_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r5_0x000ab000),
    kInstruction_cmn_vc_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r0_0x02ac0000),
    kInstruction_cmn_ge_r0_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r5_0x000002ac),
    kInstruction_cmn_pl_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r13_0x00000ab0),
    kInstruction_cmn_ge_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r2_0x03fc0000),
    kInstruction_cmn_eq_r2_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r11_0x00000ab0),
    kInstruction_cmn_lt_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r6_0x00000000),
    kInstruction_cmn_ge_r6_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r2_0xac000002),
    kInstruction_cmn_gt_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r15_0x000000ab),
    kInstruction_cmn_le_r15_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r4_0x00000ff0),
    kInstruction_cmn_cc_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0x02ac0000),
    kInstruction_cmn_pl_r10_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r9_0x00000000),
    kInstruction_cmn_gt_r9_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r8_0x000000ff),
    kInstruction_cmn_vs_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r14_0x0002ac00),
    kInstruction_cmn_gt_r14_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r14_0x00002ac0),
    kInstruction_cmn_vs_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r12_0x00000000),
    kInstruction_cmn_ge_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r8_0xf000000f),
    kInstruction_cmn_vc_r8_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r6_0x00003fc0),
    kInstruction_cmn_cs_r6_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r4_0x000003fc),
    kInstruction_cmn_le_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r5_0x000ff000),
    kInstruction_cmn_cs_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r2_0x0000ff00),
    kInstruction_cmn_eq_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0x0ab00000),
    kInstruction_cmn_pl_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r11_0xac000002),
    kInstruction_cmn_le_r11_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r15_0x00003fc0),
    kInstruction_cmn_vs_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r2_0x0002ac00),
    kInstruction_cmn_lt_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r1_0x00ab0000),
    kInstruction_cmn_eq_r1_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r7_0x03fc0000),
    kInstruction_cmn_cc_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x00000ab0),
    kInstruction_cmn_mi_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r4_0x00000ab0),
    kInstruction_cmn_eq_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r3_0x0003fc00),
    kInstruction_cmn_ls_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x000ab000),
    kInstruction_cmn_mi_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r12_0x003fc000),
    kInstruction_cmn_ne_r12_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r11_0x00ff0000),
    kInstruction_cmn_eq_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r13_0x00ab0000),
    kInstruction_cmn_cs_r13_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r5_0x000003fc),
    kInstruction_cmn_eq_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r6_0x0003fc00),
    kInstruction_cmn_vs_r6_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r8_0x0ff00000),
    kInstruction_cmn_pl_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r11_0x0000ab00),
    kInstruction_cmn_pl_r11_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r2_0xac000002),
    kInstruction_cmn_le_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r10_0x000ff000),
    kInstruction_cmn_vc_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r4_0x00000ff0),
    kInstruction_cmn_le_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r12_0x00000ff0),
    kInstruction_cmn_gt_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r5_0x0002ac00),
    kInstruction_cmn_le_r5_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r0_0xac000002),
    kInstruction_cmn_le_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r11_0x0ff00000),
    kInstruction_cmn_vs_r11_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r0_0x000ab000),
    kInstruction_cmn_ls_r0_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r2_0xf000000f),
    kInstruction_cmn_ls_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r3_0x0ff00000),
    kInstruction_cmn_cs_r3_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r8_0x0ff00000),
    kInstruction_cmn_hi_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r3_0x00002ac0),
    kInstruction_cmn_gt_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r15_0xab000000),
    kInstruction_cmn_al_r15_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r13_0x000000ab),
    kInstruction_cmn_eq_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r2_0xc000002a),
    kInstruction_cmn_al_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r13_0x03fc0000),
    kInstruction_cmn_eq_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r3_0x00000ff0),
    kInstruction_cmn_eq_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r12_0x00002ac0),
    kInstruction_cmn_hi_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r2_0x0ff00000),
    kInstruction_cmn_mi_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r9_0x003fc000),
    kInstruction_cmn_ne_r9_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r14_0x03fc0000),
    kInstruction_cmn_eq_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r0_0x002ac000),
    kInstruction_cmn_cc_r0_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r14_0x00000ab0),
    kInstruction_cmn_vc_r14_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r15_0xf000000f),
    kInstruction_cmn_mi_r15_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r9_0x000003fc),
    kInstruction_cmn_ge_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r13_0xac000002),
    kInstruction_cmn_vs_r13_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r1_0x3fc00000),
    kInstruction_cmn_vs_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r12_0x00003fc0),
    kInstruction_cmn_eq_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0xff000000),
    kInstruction_cmn_mi_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r5_0x000003fc),
    kInstruction_cmn_ne_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r8_0x0ff00000),
    kInstruction_cmn_lt_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r7_0x3fc00000),
    kInstruction_cmn_hi_r7_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r10_0xac000002),
    kInstruction_cmn_ge_r10_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0x0000ff00),
    kInstruction_cmn_vs_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r6_0x000000ab),
    kInstruction_cmn_al_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r7_0x00ff0000),
    kInstruction_cmn_ge_r7_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r0_0x000ff000),
    kInstruction_cmn_ne_r0_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x000000ab),
    kInstruction_cmn_mi_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r1_0xf000000f),
    kInstruction_cmn_hi_r1_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x2ac00000),
    kInstruction_cmn_mi_r6_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r11_0x000000ff),
    kInstruction_cmn_vc_r11_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r14_0x02ac0000),
    kInstruction_cmn_ls_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r5_0x003fc000),
    kInstruction_cmn_ge_r5_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r12_0x0000ab00),
    kInstruction_cmn_ls_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r15_0x00000ab0),
    kInstruction_cmn_cc_r15_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r12_0x0000ab00),
    kInstruction_cmn_vc_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0xc000002a),
    kInstruction_cmn_vs_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r7_0x0ab00000),
    kInstruction_cmn_lt_r7_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r6_0x00000ff0),
    kInstruction_cmn_ls_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r10_0x000000ff),
    kInstruction_cmn_vc_r10_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r4_0x0000ab00),
    kInstruction_cmn_ls_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r10_0x003fc000),
    kInstruction_cmn_mi_r10_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r1_0x000002ac),
    kInstruction_cmn_ls_r1_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r7_0xb000000a),
    kInstruction_cmn_ge_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r4_0xf000000f),
    kInstruction_cmn_gt_r4_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r8_0x002ac000),
    kInstruction_cmn_vc_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r5_0x0ab00000),
    kInstruction_cmn_eq_r5_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r2_0xf000000f),
    kInstruction_cmn_gt_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0xff000000),
    kInstruction_cmn_gt_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r8_0x0ab00000),
    kInstruction_cmn_ls_r8_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r0_0xb000000a),
    kInstruction_cmn_vc_r0_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r6_0x03fc0000),
    kInstruction_cmn_lt_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r10_0x0000ab00),
    kInstruction_cmn_ge_r10_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r4_0x000ab000),
    kInstruction_cmn_hi_r4_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r11_0x3fc00000),
    kInstruction_cmn_hi_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r12_0xc000003f),
    kInstruction_cmn_vs_r12_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r12_0xb000000a),
    kInstruction_cmn_gt_r12_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r11_0x2ac00000),
    kInstruction_cmn_eq_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r0_0xc000003f),
    kInstruction_cmn_hi_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r12_0xac000002),
    kInstruction_cmn_cs_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r9_0x3fc00000),
    kInstruction_cmn_hi_r9_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0x00002ac0),
    kInstruction_cmn_vs_r2_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r12_0xb000000a),
    kInstruction_cmn_al_r12_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r12_0x3fc00000),
    kInstruction_cmn_gt_r12_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r6_0xf000000f),
    kInstruction_cmn_gt_r6_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r14_0x000000ff),
    kInstruction_cmn_vc_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r7_0x0002ac00),
    kInstruction_cmn_pl_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r1_0x03fc0000),
    kInstruction_cmn_ge_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r10_0x0002ac00),
    kInstruction_cmn_hi_r10_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r4_0x002ac000),
    kInstruction_cmn_gt_r4_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r5_0x000000ff),
    kInstruction_cmn_vc_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r15_0x0000ab00),
    kInstruction_cmn_pl_r15_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r4_0x00ab0000),
    kInstruction_cmn_cc_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r11_0xff000000),
    kInstruction_cmn_pl_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r2_0xf000000f),
    kInstruction_cmn_pl_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r8_0xb000000a),
    kInstruction_cmn_cc_r8_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r13_0x000000ff),
    kInstruction_cmn_al_r13_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x000003fc),
    kInstruction_cmn_mi_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r13_0x02ac0000),
    kInstruction_cmn_vs_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r4_0x00ff0000),
    kInstruction_cmn_mi_r4_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r3_0x000003fc),
    kInstruction_cmn_cs_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r13_0xab000000),
    kInstruction_cmn_pl_r13_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r9_0x002ac000),
    kInstruction_cmn_ls_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r1_0xc000002a),
    kInstruction_cmn_eq_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r12_0x00000000),
    kInstruction_cmn_lt_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r14_0xff000000),
    kInstruction_cmn_ge_r14_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r9_0x002ac000),
    kInstruction_cmn_lt_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r10_0x00000ff0),
    kInstruction_cmn_lt_r10_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r5_0x000000ff),
    kInstruction_cmn_vs_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r12_0x03fc0000),
    kInstruction_cmn_cc_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r4_0x00000000),
    kInstruction_cmn_ne_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r13_0xff000000),
    kInstruction_cmn_mi_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r7_0x00000ff0),
    kInstruction_cmn_ne_r7_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0xc000003f),
    kInstruction_cmn_vs_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r5_0x00ff0000),
    kInstruction_cmn_al_r5_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r15_0x00000ff0),
    kInstruction_cmn_hi_r15_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r8_0x00003fc0),
    kInstruction_cmn_ls_r8_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r0_0xff000000),
    kInstruction_cmn_vs_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r6_0x000000ab),
    kInstruction_cmn_vs_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r9_0x00ab0000),
    kInstruction_cmn_cs_r9_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r1_0x0002ac00),
    kInstruction_cmn_hi_r1_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r15_0x2ac00000),
    kInstruction_cmn_hi_r15_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r6_0x0002ac00),
    kInstruction_cmn_hi_r6_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r4_0xc000003f),
    kInstruction_cmn_ge_r4_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r10_0x0000ff00),
    kInstruction_cmn_ls_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r11_0x000003fc),
    kInstruction_cmn_ne_r11_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r3_0x0002ac00),
    kInstruction_cmn_ls_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r12_0x000003fc),
    kInstruction_cmn_al_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r7_0xf000000f),
    kInstruction_cmn_le_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r11_0x00000ab0),
    kInstruction_cmn_al_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r13_0x02ac0000),
    kInstruction_cmn_cs_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r1_0x00000ff0),
    kInstruction_cmn_hi_r1_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r11_0x3fc00000),
    kInstruction_cmn_le_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r9_0x000003fc),
    kInstruction_cmn_hi_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r13_0x000002ac),
    kInstruction_cmn_mi_r13_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r12_0x000003fc),
    kInstruction_cmn_lt_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r14_0x00000ab0),
    kInstruction_cmn_lt_r14_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r1_0x3fc00000),
    kInstruction_cmn_gt_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r14_0xb000000a),
    kInstruction_cmn_cc_r14_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r0_0x000002ac),
    kInstruction_cmn_ge_r0_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r12_0x000003fc),
    kInstruction_cmn_eq_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r13_0x0ab00000),
    kInstruction_cmn_vc_r13_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r10_0x0003fc00),
    kInstruction_cmn_pl_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r7_0x0000ff00),
    kInstruction_cmn_le_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r5_0x0003fc00),
    kInstruction_cmn_eq_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r1_0xfc000003),
    kInstruction_cmn_pl_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r15_0x000ff000),
    kInstruction_cmn_gt_r15_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r2_0xb000000a),
    kInstruction_cmn_mi_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r8_0x0000ff00),
    kInstruction_cmn_cs_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r8_0x00002ac0),
    kInstruction_cmn_vs_r8_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r5_0x00ab0000),
    kInstruction_cmn_cs_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r3_0x00ab0000),
    kInstruction_cmn_pl_r3_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r5_0x02ac0000),
    kInstruction_cmn_hi_r5_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r9_0x000002ac),
    kInstruction_cmn_cc_r9_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r13_0x0000ab00),
    kInstruction_cmn_ls_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r11_0x00000ab0),
    kInstruction_cmn_pl_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r14_0x3fc00000),
    kInstruction_cmn_ge_r14_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r14_0x0000ab00),
    kInstruction_cmn_al_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r6_0xac000002),
    kInstruction_cmn_lt_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r3_0x000ff000),
    kInstruction_cmn_vc_r3_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r8_0xfc000003),
    kInstruction_cmn_ne_r8_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r6_0x000ab000),
    kInstruction_cmn_cs_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r15_0x0002ac00),
    kInstruction_cmn_hi_r15_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r6_0x00000ff0),
    kInstruction_cmn_pl_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r15_0x03fc0000),
    kInstruction_cmn_hi_r15_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r6_0x0003fc00),
    kInstruction_cmn_cc_r6_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r12_0x000002ac),
    kInstruction_cmn_eq_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r11_0x02ac0000),
    kInstruction_cmn_ls_r11_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r13_0x00ff0000),
    kInstruction_cmn_ge_r13_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r4_0x0003fc00),
    kInstruction_cmn_lt_r4_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r0_0x0000ab00),
    kInstruction_cmn_mi_r0_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r4_0x000000ab),
    kInstruction_cmn_lt_r4_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r2_0xc000003f),
    kInstruction_cmn_ls_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r1_0x000000ab),
    kInstruction_cmn_pl_r1_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r10_0x0000ff00),
    kInstruction_cmn_ne_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r15_0x00000ab0),
    kInstruction_cmn_vc_r15_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r6_0x02ac0000),
    kInstruction_cmn_eq_r6_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r11_0x00000000),
    kInstruction_cmn_cc_r11_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r7_0x002ac000),
    kInstruction_cmn_mi_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r14_0xab000000),
    kInstruction_cmn_hi_r14_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r6_0x0000ff00),
    kInstruction_cmn_vc_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r5_0x000002ac),
    kInstruction_cmn_al_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r12_0x0002ac00),
    kInstruction_cmn_cc_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r10_0x000000ab),
    kInstruction_cmn_cc_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r5_0x000002ac),
    kInstruction_cmn_gt_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r3_0x00000000),
    kInstruction_cmn_vc_r3_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r12_0xac000002),
    kInstruction_cmn_gt_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r10_0x00ab0000),
    kInstruction_cmn_al_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r5_0x000ff000),
    kInstruction_cmn_mi_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r1_0x00000ff0),
    kInstruction_cmn_pl_r1_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r7_0xf000000f),
    kInstruction_cmn_lt_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r14_0x002ac000),
    kInstruction_cmn_ge_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r0_0xac000002),
    kInstruction_cmn_cc_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r2_0x00000ab0),
    kInstruction_cmn_cs_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r0_0x00002ac0),
    kInstruction_cmn_vs_r0_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r10_0x000ab000),
    kInstruction_cmn_le_r10_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r9_0x0003fc00),
    kInstruction_cmn_ge_r9_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r1_0x00003fc0),
    kInstruction_cmn_lt_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r5_0x000000ff),
    kInstruction_cmn_ge_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r11_0x2ac00000),
    kInstruction_cmn_le_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r9_0x002ac000),
    kInstruction_cmn_le_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r12_0xf000000f),
    kInstruction_cmn_hi_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r3_0x02ac0000),
    kInstruction_cmn_lt_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r13_0x2ac00000),
    kInstruction_cmn_al_r13_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r12_0x00000ab0),
    kInstruction_cmn_vs_r12_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r3_0x3fc00000),
    kInstruction_cmn_gt_r3_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r0_0x2ac00000),
    kInstruction_cmn_gt_r0_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r15_0x000002ac),
    kInstruction_cmn_eq_r15_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r1_0x000ab000),
    kInstruction_cmn_gt_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r2_0x2ac00000),
    kInstruction_cmn_gt_r2_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r15_0x00ab0000),
    kInstruction_cmn_mi_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r1_0x000ab000),
    kInstruction_cmn_mi_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r12_0x0ab00000),
    kInstruction_cmn_ge_r12_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r5_0x000000ab),
    kInstruction_cmn_gt_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r4_0x00000000),
    kInstruction_cmn_gt_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r13_0xc000003f),
    kInstruction_cmn_al_r13_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r7_0xff000000),
    kInstruction_cmn_ls_r7_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r0_0x00000ff0),
    kInstruction_cmn_vs_r0_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r9_0x02ac0000),
    kInstruction_cmn_hi_r9_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r1_0xc000002a),
    kInstruction_cmn_cs_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r8_0xf000000f),
    kInstruction_cmn_hi_r8_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r1_0xb000000a),
    kInstruction_cmn_gt_r1_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r2_0x0002ac00),
    kInstruction_cmn_gt_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r5_0x000000ab),
    kInstruction_cmn_vs_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r12_0x000ff000),
    kInstruction_cmn_cc_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r0_0x00003fc0),
    kInstruction_cmn_ge_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r12_0x00ab0000),
    kInstruction_cmn_ls_r12_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r4_0x000003fc),
    kInstruction_cmn_vs_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r4_0x00003fc0),
    kInstruction_cmn_ls_r4_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r9_0xb000000a),
    kInstruction_cmn_eq_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r9_0x2ac00000),
    kInstruction_cmn_cs_r9_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r12_0x0000ff00),
    kInstruction_cmn_vs_r12_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r1_0x0000ff00),
    kInstruction_cmn_vc_r1_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r12_0xff000000),
    kInstruction_cmn_hi_r12_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r12_0x0002ac00),
    kInstruction_cmn_cs_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r11_0x03fc0000),
    kInstruction_cmn_mi_r11_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r2_0x000ff000),
    kInstruction_cmn_eq_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r6_0x00000ff0),
    kInstruction_cmn_al_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r7_0x000003fc),
    kInstruction_cmn_cs_r7_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r11_0xb000000a),
    kInstruction_cmn_pl_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r15_0x000ff000),
    kInstruction_cmn_ne_r15_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r14_0x00ab0000),
    kInstruction_cmn_mi_r14_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r4_0x0000ff00),
    kInstruction_cmn_hi_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r1_0x000002ac),
    kInstruction_cmn_ge_r1_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r7_0xb000000a),
    kInstruction_cmn_gt_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r2_0x00000000),
    kInstruction_cmn_gt_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r2_0xb000000a),
    kInstruction_cmn_cc_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r14_0x000ab000),
    kInstruction_cmn_vs_r14_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r5_0x000002ac),
    kInstruction_cmn_lt_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r13_0x0000ff00),
    kInstruction_cmn_cc_r13_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r15_0x000002ac),
    kInstruction_cmn_hi_r15_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r1_0x00ff0000),
    kInstruction_cmn_ge_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r15_0x00002ac0),
    kInstruction_cmn_lt_r15_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r8_0x000ff000),
    kInstruction_cmn_lt_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r10_0xc000002a),
    kInstruction_cmn_hi_r10_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r12_0x000ab000),
    kInstruction_cmn_eq_r12_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r11_0x00002ac0),
    kInstruction_cmn_vs_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r10_0x000003fc),
    kInstruction_cmn_hi_r10_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r8_0x000003fc),
    kInstruction_cmn_cc_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r11_0x00000ab0),
    kInstruction_cmn_vc_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r3_0xac000002),
    kInstruction_cmn_le_r3_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r11_0xc000002a),
    kInstruction_cmn_cc_r11_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r6_0xab000000),
    kInstruction_cmn_lt_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r1_0x00003fc0),
    kInstruction_cmn_hi_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r3_0x00002ac0),
    kInstruction_cmn_vc_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r6_0x00000ab0),
    kInstruction_cmn_vc_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r6_0x03fc0000),
    kInstruction_cmn_ls_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r11_0x0ab00000),
    kInstruction_cmn_hi_r11_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r12_0x0002ac00),
    kInstruction_cmn_lt_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r8_0xab000000),
    kInstruction_cmn_al_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0x00000ab0),
    kInstruction_cmn_vs_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r14_0x02ac0000),
    kInstruction_cmn_hi_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r3_0x00000ff0),
    kInstruction_cmn_cs_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r9_0xb000000a),
    kInstruction_cmn_cc_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r9_0x00000ff0),
    kInstruction_cmn_vc_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r9_0xab000000),
    kInstruction_cmn_ne_r9_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r10_0xb000000a),
    kInstruction_cmn_cc_r10_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r11_0xb000000a),
    kInstruction_cmn_ls_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r11_0x00ff0000),
    kInstruction_cmn_lt_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r3_0x000003fc),
    kInstruction_cmn_lt_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r14_0x00002ac0),
    kInstruction_cmn_gt_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r8_0xc000003f),
    kInstruction_cmn_ls_r8_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r11_0x000ab000),
    kInstruction_cmn_al_r11_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r7_0x000ab000),
    kInstruction_cmn_lt_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r14_0xff000000),
    kInstruction_cmn_vs_r14_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r2_0xab000000),
    kInstruction_cmn_vc_r2_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r3_0x00000ff0),
    kInstruction_cmn_ne_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r15_0x02ac0000),
    kInstruction_cmn_ne_r15_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r3_0x000ff000),
    kInstruction_cmn_gt_r3_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r1_0x2ac00000),
    kInstruction_cmn_pl_r1_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r1_0x00002ac0),
    kInstruction_cmn_mi_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r6_0xac000002),
    kInstruction_cmn_vc_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0x0ff00000),
    kInstruction_cmn_vs_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r2_0x000003fc),
    kInstruction_cmn_ge_r2_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r15_0x0000ff00),
    kInstruction_cmn_cs_r15_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r3_0x000002ac),
    kInstruction_cmn_lt_r3_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r6_0xff000000),
    kInstruction_cmn_cs_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r14_0x000000ff),
    kInstruction_cmn_ge_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r7_0x03fc0000),
    kInstruction_cmn_gt_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r8_0x000ff000),
    kInstruction_cmn_ne_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r14_0xc000002a),
    kInstruction_cmn_gt_r14_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r12_0x0000ff00),
    kInstruction_cmn_hi_r12_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r15_0x00003fc0),
    kInstruction_cmn_le_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r13_0x000ab000),
    kInstruction_cmn_eq_r13_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r7_0x000ab000),
    kInstruction_cmn_vc_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_gt_r7_0xf000000f),
    kInstruction_cmn_gt_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r6_0xac000002),
    kInstruction_cmn_cc_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r14_0x000000ff),
    kInstruction_cmn_cs_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r2_0x0003fc00),
    kInstruction_cmn_ne_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r1_0x002ac000),
    kInstruction_cmn_vs_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r8_0x002ac000),
    kInstruction_cmn_eq_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r8_0x0000ff00),
    kInstruction_cmn_lt_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r9_0xc000003f),
    kInstruction_cmn_vs_r9_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r11_0xff000000),
    kInstruction_cmn_mi_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cs_r12_0x03fc0000),
    kInstruction_cmn_cs_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r5_0xc000002a),
    kInstruction_cmn_lt_r5_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r6_0x000000ab),
    kInstruction_cmn_vc_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r10_0x0ab00000),
    kInstruction_cmn_ls_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r11_0x00ff0000),
    kInstruction_cmn_al_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r13_0x00000ab0),
    kInstruction_cmn_hi_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r0_0xab000000),
    kInstruction_cmn_ls_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r5_0xab000000),
    kInstruction_cmn_le_r5_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r4_0x00ff0000),
    kInstruction_cmn_vs_r4_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r10_0x03fc0000),
    kInstruction_cmn_al_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r8_0x000003fc),
    kInstruction_cmn_al_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r11_0xab000000),
    kInstruction_cmn_vs_r11_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r2_0x00000ff0),
    kInstruction_cmn_eq_r2_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r4_0x00000ff0),
    kInstruction_cmn_vc_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r9_0x00002ac0),
    kInstruction_cmn_vc_r9_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r11_0x00ff0000),
    kInstruction_cmn_cc_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r13_0x00ff0000),
    kInstruction_cmn_cc_r13_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r0_0x00000ab0),
    kInstruction_cmn_pl_r0_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_al_r2_0x02ac0000),
    kInstruction_cmn_al_r2_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r11_0xc000002a),
    kInstruction_cmn_hi_r11_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ne_r3_0xf000000f),
    kInstruction_cmn_ne_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r15_0x0ab00000),
    kInstruction_cmn_cc_r15_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ge_r12_0x00ff0000),
    kInstruction_cmn_ge_r12_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r12_0x002ac000),
    kInstruction_cmn_le_r12_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r12_0xc000003f),
    kInstruction_cmn_mi_r12_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r0_0xfc000003),
    kInstruction_cmn_lt_r0_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r15_0x000ab000),
    kInstruction_cmn_vc_r15_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r5_0x3fc00000),
    kInstruction_cmn_pl_r5_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r15_0x00ab0000),
    kInstruction_cmn_vs_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_hi_r3_0x00ff0000),
    kInstruction_cmn_hi_r3_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r8_0x000000ff),
    kInstruction_cmn_lt_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r2_0x000000ff),
    kInstruction_cmn_le_r2_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r0_0x0002ac00),
    kInstruction_cmn_vs_r0_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r2_0xff000000),
    kInstruction_cmn_vs_r2_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r6_0xab000000),
    kInstruction_cmn_pl_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r4_0x3fc00000),
    kInstruction_cmn_ls_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r3_0x000ab000),
    kInstruction_cmn_ls_r3_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r11_0x000ab000),
    kInstruction_cmn_eq_r11_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r6_0x03fc0000),
    kInstruction_cmn_vc_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r14_0x0000ab00),
    kInstruction_cmn_mi_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r8_0xab000000),
    kInstruction_cmn_pl_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r8_0xc000003f),
    kInstruction_cmn_pl_r8_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_eq_r14_0x003fc000),
    kInstruction_cmn_eq_r14_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r9_0x00ff0000),
    kInstruction_cmn_vs_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vs_r1_0x00002ac0),
    kInstruction_cmn_vs_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_le_r1_0x00ff0000),
    kInstruction_cmn_le_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r7_0x000ff000),
    kInstruction_cmn_lt_r7_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_mi_r6_0x002ac000),
    kInstruction_cmn_mi_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_vc_r11_0xc000003f),
    kInstruction_cmn_vc_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_lt_r4_0x00000000),
    kInstruction_cmn_lt_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_pl_r0_0xac000002),
    kInstruction_cmn_pl_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_ls_r10_0xc000003f),
    kInstruction_cmn_ls_r10_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmn_cc_r15_0xc000002a),
    kInstruction_cmn_cc_r15_0xc000002a,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMN_A32_H_
